# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/request/request_vod.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from volcengine.vod.models.business import vod_workflow_pb2 as vod_dot_business_dot_vod__workflow__pb2
from volcengine.vod.models.business import vod_upload_pb2 as vod_dot_business_dot_vod__upload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvod/request/request_vod.proto\x12\x1dVolcengine.Vod.Models.Request\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fvod/business/vod_workflow.proto\x1a\x1dvod/business/vod_upload.proto\"\x84\x03\n\x18VodGetAllPlayInfoRequest\x12\x0c\n\x04Vids\x18\x01 \x01(\t\x12\x0f\n\x07\x46ormats\x18\x02 \x01(\t\x12\x0e\n\x06\x43odecs\x18\x03 \x01(\t\x12\x13\n\x0b\x44\x65\x66initions\x18\x04 \x01(\t\x12\x11\n\tFileTypes\x18\x05 \x01(\t\x12\x11\n\tLogoTypes\x18\x06 \x01(\t\x12\x19\n\x11NeedEncryptStream\x18\x07 \x01(\t\x12\x0b\n\x03Ssl\x18\x08 \x01(\t\x12\x12\n\nNeedThumbs\x18\t \x01(\t\x12\x17\n\x0fNeedBarrageMask\x18\n \x01(\t\x12\x0f\n\x07\x43\x64nType\x18\x0b \x01(\t\x12\x11\n\tUnionInfo\x18\x0c \x01(\t\x12\x11\n\tPlayScene\x18\r \x01(\t\x12\x1a\n\x12\x44rmExpireTimestamp\x18\x0e \x01(\t\x12\x0f\n\x07HDRType\x18\x0f \x01(\t\x12 \n\x18KeyFrameAlignmentVersion\x18\x10 \x01(\t\x12\x12\n\nUserAction\x18\x11 \x01(\t\x12\x0f\n\x07Quality\x18\x12 \x01(\t\"\xc0\x02\n\x15VodGetPlayInfoRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x02 \x01(\t\x12\r\n\x05\x43odec\x18\x03 \x01(\t\x12\x12\n\nDefinition\x18\x04 \x01(\t\x12\x10\n\x08\x46ileType\x18\x05 \x01(\t\x12\x10\n\x08LogoType\x18\x06 \x01(\t\x12\x0e\n\x06\x42\x61se64\x18\x07 \x01(\t\x12\x0b\n\x03Ssl\x18\x08 \x01(\t\x12\x12\n\nNeedThumbs\x18\t \x01(\t\x12\x17\n\x0fNeedBarrageMask\x18\n \x01(\t\x12\x0f\n\x07\x43\x64nType\x18\x0b \x01(\t\x12\x11\n\tUnionInfo\x18\x0c \x01(\t\x12\x15\n\rHDRDefinition\x18\r \x01(\t\x12\x11\n\tPlayScene\x18\x0e \x01(\t\x12\x1a\n\x12\x44rmExpireTimestamp\x18\x0f \x01(\t\x12\x0f\n\x07Quality\x18\x10 \x01(\t\"g\n\x1fVodGetPrivateDrmPlayAuthRequest\x12\x0f\n\x07\x44rmType\x18\x01 \x01(\t\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\x13\n\x0bPlayAuthIds\x18\x03 \x01(\t\x12\x11\n\tUnionInfo\x18\x04 \x01(\t\"Q\n\x1dVodGetHlsDecryptionKeyRequest\x12\x14\n\x0c\x44rmAuthToken\x18\x01 \x01(\t\x12\n\n\x02\x41k\x18\x02 \x01(\t\x12\x0e\n\x06Source\x18\x03 \x01(\t\"\x98\x01\n+VodGetPlayInfoWithLiveTimeShiftSceneRequest\x12\x11\n\tStoreUris\x18\x01 \x01(\t\x12\x11\n\tSpaceName\x18\x02 \x01(\t\x12\x0b\n\x03Ssl\x18\x03 \x01(\t\x12\x17\n\x0f\x45xpireTimestamp\x18\x04 \x01(\t\x12\x1d\n\x15NeedComposeBucketName\x18\x05 \x01(\t\"m\n\x13VodUrlUploadRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x43\n\x07URLSets\x18\x02 \x03(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodUrlUploadURLSet\"/\n\x1dVodQueryUploadTaskInfoRequest\x12\x0e\n\x06JobIds\x18\x01 \x01(\t\"x\n\x19VodApplyUploadInfoRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x12\n\nSessionKey\x18\x02 \x01(\t\x12\x10\n\x08\x46ileSize\x18\x03 \x01(\x01\x12\x10\n\x08\x46ileType\x18\x04 \x01(\t\x12\x10\n\x08\x46ileName\x18\x05 \x01(\t\"w\n\x15VodUploadMediaRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x10\n\x08\x46ilePath\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\x12\x11\n\tFunctions\x18\x04 \x01(\t\x12\x10\n\x08\x46ileName\x18\x05 \x01(\t\"\x8c\x01\n\x18VodUploadMaterialRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x10\n\x08\x46ilePath\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\x12\x11\n\tFunctions\x18\x04 \x01(\t\x12\x10\n\x08\x46ileType\x18\x05 \x01(\t\x12\x10\n\x08\x46ileName\x18\x06 \x01(\t\"l\n\x1aVodCommitUploadInfoRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x12\n\nSessionKey\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\x12\x11\n\tFunctions\x18\x04 \x01(\t\"=\n\x17VodUrlUploadJsonRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0f\n\x07URLSets\x18\x02 \x01(\t\".\n\x1eVodGetRecommendedPosterRequest\x12\x0c\n\x04Vids\x18\x01 \x01(\t\"A\n\"VodUpdateMediaPublishStatusRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06Status\x18\x02 \x01(\t\"\x9c\x02\n\x19VodUpdateMediaInfoRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12/\n\tPosterUri\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05Title\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x44\x65scription\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04Tags\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x10\x43lassificationId\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\'\n\x17VodGetMediaInfosRequest\x12\x0c\n\x04Vids\x18\x01 \x01(\t\";\n\x15VodDeleteMediaRequest\x12\x0c\n\x04Vids\x18\x01 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x02 \x01(\t\"P\n\x1aVodDeleteTranscodesRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0f\n\x07\x46ileIds\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\"\xc6\x01\n\x16VodGetMediaListRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\x0e\n\x06Status\x18\x03 \x01(\t\x12\r\n\x05Order\x18\x04 \x01(\t\x12\x0c\n\x04Tags\x18\x05 \x01(\t\x12\x11\n\tStartTime\x18\x06 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x07 \x01(\t\x12\x0e\n\x06Offset\x18\x08 \x01(\t\x12\x10\n\x08PageSize\x18\t \x01(\t\x12\x19\n\x11\x43lassificationIds\x18\n \x01(\t\"\xe6\x01\n\x1dVodGetSubtitleInfoListRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0f\n\x07\x46ileIds\x18\x02 \x01(\t\x12\x11\n\tLanguages\x18\x03 \x01(\t\x12\x0f\n\x07\x46ormats\x18\x04 \x01(\t\x12\x13\n\x0bLanguageIds\x18\x05 \x01(\t\x12\x13\n\x0bSubtitleIds\x18\x06 \x01(\t\x12\x0e\n\x06Status\x18\x07 \x01(\t\x12\r\n\x05Title\x18\x08 \x01(\t\x12\x0b\n\x03Tag\x18\t \x01(\t\x12\x0e\n\x06Offset\x18\n \x01(\t\x12\x10\n\x08PageSize\x18\x0b \x01(\t\x12\x0b\n\x03Ssl\x18\x0c \x01(\t\"r\n\x1eVodUpdateSubtitleStatusRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0f\n\x07\x46ileIds\x18\x02 \x01(\t\x12\x11\n\tLanguages\x18\x03 \x01(\t\x12\x0f\n\x07\x46ormats\x18\x04 \x01(\t\x12\x0e\n\x06Status\x18\x05 \x01(\t\"\xb5\x01\n\x1cVodUpdateSubtitleInfoRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06\x46ileId\x18\x02 \x01(\t\x12\x10\n\x08Language\x18\x03 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x04 \x01(\t\x12+\n\x05Title\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03Tag\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"w\n VodGetAuditFramesForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\x12\x19\n\x11MinNumberOfFrames\x18\x03 \x01(\t\x12\x19\n\x11MaxNumberOfFrames\x18\x04 \x01(\t\"\xa1\x02\n\x1dVodGetMLFramesForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\x12\x10\n\x08\x46rameOpt\x18\x03 \x01(\t\x12\x10\n\x08\x46rameFps\x18\x04 \x01(\t\x12\x16\n\x0eNumberOfFrames\x18\x05 \x01(\t\x12\x14\n\x0c\x43utTimeMills\x18\x06 \x01(\t\x12\x16\n\x0eNeedFirstFrame\x18\x07 \x01(\t\x12\x15\n\rNeedLastFrame\x18\x08 \x01(\t\x12\x15\n\rStartTimeMill\x18\t \x01(\t\x12\x13\n\x0b\x45ndTimeMill\x18\n \x01(\t\x12\x19\n\x11MinNumberOfFrames\x18\x0b \x01(\t\x12\x19\n\x11MaxNumberOfFrames\x18\x0c \x01(\t\"U\n!VodGetBetterFramesForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\x12\x11\n\tCoverRate\x18\x03 \x01(\t\"?\n\x1eVodGetAudioInfoForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\"P\n/VodGetAutomaticSpeechRecognitionForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\"I\n(VodGetAudioEventDetectionForAuditRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x10\n\x08Strategy\x18\x02 \x01(\t\"q\n#VodCreateVideoClassificationRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\r\n\x05Level\x18\x02 \x01(\x05\x12\x10\n\x08ParentId\x18\x03 \x01(\x03\x12\x16\n\x0e\x43lassification\x18\x04 \x01(\t\"j\n#VodUpdateVideoClassificationRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x02 \x01(\x03\x12\x16\n\x0e\x43lassification\x18\x03 \x01(\t\"R\n#VodDeleteVideoClassificationRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x02 \x01(\x03\"Q\n\"VodListVideoClassificationsRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x02 \x01(\x03\"&\n\x17VodListSnapshotsRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\"\xbc\x01\n\x17VodStartWorkflowRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x12\n\nTemplateId\x18\x02 \x01(\t\x12=\n\x05Input\x18\x03 \x01(\x0b\x32..Volcengine.Vod.Models.Business.WorkflowParams\x12\x10\n\x08Priority\x18\x04 \x01(\x05\x12\x14\n\x0c\x43\x61llbackArgs\x18\x05 \x01(\t\x12\x19\n\x11\x45nableLowPriority\x18\x06 \x01(\x08\"D\n!VodRetrieveTranscodeResultRequest\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x12\n\nResultType\x18\x02 \x01(\t\"v\n\x15VodCreateSpaceRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x13\n\x0bProjectName\x18\x02 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06Region\x18\x04 \x01(\t\x12\x10\n\x08UserName\x18\x05 \x01(\t\"-\n\x18VodGetSpaceDetailRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\"4\n\x13VodListSpaceRequest\x12\x0e\n\x06Offset\x18\x01 \x01(\x01\x12\r\n\x05Limit\x18\x02 \x01(\x01\"u\n\x15VodUpdateSpaceRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x19\n\x11SourceProjectName\x18\x02 \x01(\t\x12\x19\n\x11TargetProjectName\x18\x03 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x04 \x01(\t\"^\n!VodUpdateSpaceUploadConfigRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x11\n\tConfigKey\x18\x02 \x01(\t\x12\x13\n\x0b\x43onfigValue\x18\x03 \x01(\t\")\n\x14VodListDomainRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\"O\n\x1eVodCreateCdnRefreshTaskRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0c\n\x04Urls\x18\x02 \x01(\t\x12\x0c\n\x04Type\x18\x03 \x01(\t\"A\n\x1eVodCreateCdnPreloadTaskRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0c\n\x04Urls\x18\x02 \x01(\t\"\xc2\x01\n\x16VodListCdnTasksRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0e\n\x06TaskId\x18\x02 \x01(\t\x12\x12\n\nDomainName\x18\x03 \x01(\t\x12\x10\n\x08TaskType\x18\x04 \x01(\t\x12\x0e\n\x06Status\x18\x05 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x06 \x01(\x05\x12\x14\n\x0c\x45ndTimestamp\x18\x07 \x01(\x05\x12\x0f\n\x07PageNum\x18\x08 \x01(\x05\x12\x10\n\x08PageSize\x18\t \x01(\x05\"n\n\x1aVodListCdnAccessLogRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x02 \x01(\x05\x12\x14\n\x0c\x45ndTimestamp\x18\x03 \x01(\x05\x12\x11\n\tSpaceName\x18\x04 \x01(\t\"p\n\x1dVodListCdnTopAccessUrlRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x02 \x01(\x05\x12\x14\n\x0c\x45ndTimestamp\x18\x03 \x01(\x05\x12\x10\n\x08SortType\x18\x04 \x01(\t\"\x8e\x01\n(VodDescribeVodDomainBandwidthDataRequest\x12\x12\n\nDomainList\x18\x01 \x01(\t\x12\x11\n\tStartTime\x18\x02 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\t\x12\x13\n\x0b\x41ggregation\x18\x04 \x01(\x05\x12\x15\n\rBandwidthType\x18\x05 \x01(\t\"\x8f\x01\n\x1aVodListCdnUsageDataRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x10\n\x08Interval\x18\x02 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x03 \x01(\x03\x12\x14\n\x0c\x45ndTimestamp\x18\x04 \x01(\x03\x12\x10\n\x08\x44\x61taType\x18\x05 \x01(\t\x12\x0e\n\x06Metric\x18\x06 \x01(\t\"\x90\x01\n\x1bVodListCdnStatusDataRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x10\n\x08Interval\x18\x02 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x03 \x01(\x03\x12\x14\n\x0c\x45ndTimestamp\x18\x04 \x01(\x03\x12\x10\n\x08\x44\x61taType\x18\x05 \x01(\t\x12\x0e\n\x06Metric\x18\x06 \x01(\t\"\'\n\x18VodDescribeIPInfoRequest\x12\x0b\n\x03Ips\x18\x01 \x01(\t\"|\n\x17VodListCdnPvDataRequest\x12\x0f\n\x07\x44omains\x18\x01 \x01(\t\x12\x10\n\x08Interval\x18\x02 \x01(\t\x12\x16\n\x0eStartTimestamp\x18\x03 \x01(\x03\x12\x14\n\x0c\x45ndTimestamp\x18\x04 \x01(\x03\x12\x10\n\x08\x44\x61taType\x18\x05 \x01(\t\"C\n!VodAddCallbackSubscriptionRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0b\n\x03Url\x18\x02 \x01(\t\"h\n\x1aVodSetCallbackEventRequest\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0e\n\x06\x45vents\x18\x02 \x01(\t\x12\x13\n\x0b\x41uthEnabled\x18\x03 \x01(\t\x12\x12\n\nPrivateKey\x18\x04 \x01(\t\"\xf4\x01\n&VodGetSmartStrategyLitePlayInfoRequest\x12\x0f\n\x07PlayUrl\x18\x01 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x02 \x01(\t\x12\r\n\x05\x43odec\x18\x03 \x01(\t\x12\x12\n\nDefinition\x18\x04 \x01(\t\x12\x10\n\x08\x46ileType\x18\x05 \x01(\t\x12\x10\n\x08LogoType\x18\x06 \x01(\t\x12\x0b\n\x03Ssl\x18\x07 \x01(\t\x12\x12\n\nNeedThumbs\x18\x08 \x01(\t\x12\x17\n\x0fNeedBarrageMask\x18\t \x01(\t\x12\x11\n\tUnionInfo\x18\n \x01(\t\x12\x15\n\rHDRDefinition\x18\x0b \x01(\tB\xc8\x01\n(com.volcengine.service.vod.model.requestB\nVodRequestP\x01Z@github.com/volcengine/volc-sdk-golang/service/vod/models/request\xa0\x01\x01\xd8\x01\x01\xca\x02\x1fVolc\\Service\\Vod\\Models\\Request\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETALLPLAYINFOREQUEST = DESCRIPTOR.message_types_by_name['VodGetAllPlayInfoRequest']
_VODGETPLAYINFOREQUEST = DESCRIPTOR.message_types_by_name['VodGetPlayInfoRequest']
_VODGETPRIVATEDRMPLAYAUTHREQUEST = DESCRIPTOR.message_types_by_name['VodGetPrivateDrmPlayAuthRequest']
_VODGETHLSDECRYPTIONKEYREQUEST = DESCRIPTOR.message_types_by_name['VodGetHlsDecryptionKeyRequest']
_VODGETPLAYINFOWITHLIVETIMESHIFTSCENEREQUEST = DESCRIPTOR.message_types_by_name['VodGetPlayInfoWithLiveTimeShiftSceneRequest']
_VODURLUPLOADREQUEST = DESCRIPTOR.message_types_by_name['VodUrlUploadRequest']
_VODQUERYUPLOADTASKINFOREQUEST = DESCRIPTOR.message_types_by_name['VodQueryUploadTaskInfoRequest']
_VODAPPLYUPLOADINFOREQUEST = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoRequest']
_VODUPLOADMEDIAREQUEST = DESCRIPTOR.message_types_by_name['VodUploadMediaRequest']
_VODUPLOADMATERIALREQUEST = DESCRIPTOR.message_types_by_name['VodUploadMaterialRequest']
_VODCOMMITUPLOADINFOREQUEST = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoRequest']
_VODURLUPLOADJSONREQUEST = DESCRIPTOR.message_types_by_name['VodUrlUploadJsonRequest']
_VODGETRECOMMENDEDPOSTERREQUEST = DESCRIPTOR.message_types_by_name['VodGetRecommendedPosterRequest']
_VODUPDATEMEDIAPUBLISHSTATUSREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateMediaPublishStatusRequest']
_VODUPDATEMEDIAINFOREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateMediaInfoRequest']
_VODGETMEDIAINFOSREQUEST = DESCRIPTOR.message_types_by_name['VodGetMediaInfosRequest']
_VODDELETEMEDIAREQUEST = DESCRIPTOR.message_types_by_name['VodDeleteMediaRequest']
_VODDELETETRANSCODESREQUEST = DESCRIPTOR.message_types_by_name['VodDeleteTranscodesRequest']
_VODGETMEDIALISTREQUEST = DESCRIPTOR.message_types_by_name['VodGetMediaListRequest']
_VODGETSUBTITLEINFOLISTREQUEST = DESCRIPTOR.message_types_by_name['VodGetSubtitleInfoListRequest']
_VODUPDATESUBTITLESTATUSREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleStatusRequest']
_VODUPDATESUBTITLEINFOREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleInfoRequest']
_VODGETAUDITFRAMESFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetAuditFramesForAuditRequest']
_VODGETMLFRAMESFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetMLFramesForAuditRequest']
_VODGETBETTERFRAMESFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetBetterFramesForAuditRequest']
_VODGETAUDIOINFOFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetAudioInfoForAuditRequest']
_VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetAutomaticSpeechRecognitionForAuditRequest']
_VODGETAUDIOEVENTDETECTIONFORAUDITREQUEST = DESCRIPTOR.message_types_by_name['VodGetAudioEventDetectionForAuditRequest']
_VODCREATEVIDEOCLASSIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['VodCreateVideoClassificationRequest']
_VODUPDATEVIDEOCLASSIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateVideoClassificationRequest']
_VODDELETEVIDEOCLASSIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['VodDeleteVideoClassificationRequest']
_VODLISTVIDEOCLASSIFICATIONSREQUEST = DESCRIPTOR.message_types_by_name['VodListVideoClassificationsRequest']
_VODLISTSNAPSHOTSREQUEST = DESCRIPTOR.message_types_by_name['VodListSnapshotsRequest']
_VODSTARTWORKFLOWREQUEST = DESCRIPTOR.message_types_by_name['VodStartWorkflowRequest']
_VODRETRIEVETRANSCODERESULTREQUEST = DESCRIPTOR.message_types_by_name['VodRetrieveTranscodeResultRequest']
_VODCREATESPACEREQUEST = DESCRIPTOR.message_types_by_name['VodCreateSpaceRequest']
_VODGETSPACEDETAILREQUEST = DESCRIPTOR.message_types_by_name['VodGetSpaceDetailRequest']
_VODLISTSPACEREQUEST = DESCRIPTOR.message_types_by_name['VodListSpaceRequest']
_VODUPDATESPACEREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateSpaceRequest']
_VODUPDATESPACEUPLOADCONFIGREQUEST = DESCRIPTOR.message_types_by_name['VodUpdateSpaceUploadConfigRequest']
_VODLISTDOMAINREQUEST = DESCRIPTOR.message_types_by_name['VodListDomainRequest']
_VODCREATECDNREFRESHTASKREQUEST = DESCRIPTOR.message_types_by_name['VodCreateCdnRefreshTaskRequest']
_VODCREATECDNPRELOADTASKREQUEST = DESCRIPTOR.message_types_by_name['VodCreateCdnPreloadTaskRequest']
_VODLISTCDNTASKSREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnTasksRequest']
_VODLISTCDNACCESSLOGREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnAccessLogRequest']
_VODLISTCDNTOPACCESSURLREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnTopAccessUrlRequest']
_VODDESCRIBEVODDOMAINBANDWIDTHDATAREQUEST = DESCRIPTOR.message_types_by_name['VodDescribeVodDomainBandwidthDataRequest']
_VODLISTCDNUSAGEDATAREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnUsageDataRequest']
_VODLISTCDNSTATUSDATAREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnStatusDataRequest']
_VODDESCRIBEIPINFOREQUEST = DESCRIPTOR.message_types_by_name['VodDescribeIPInfoRequest']
_VODLISTCDNPVDATAREQUEST = DESCRIPTOR.message_types_by_name['VodListCdnPvDataRequest']
_VODADDCALLBACKSUBSCRIPTIONREQUEST = DESCRIPTOR.message_types_by_name['VodAddCallbackSubscriptionRequest']
_VODSETCALLBACKEVENTREQUEST = DESCRIPTOR.message_types_by_name['VodSetCallbackEventRequest']
_VODGETSMARTSTRATEGYLITEPLAYINFOREQUEST = DESCRIPTOR.message_types_by_name['VodGetSmartStrategyLitePlayInfoRequest']
VodGetAllPlayInfoRequest = _reflection.GeneratedProtocolMessageType('VodGetAllPlayInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETALLPLAYINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAllPlayInfoRequest)
  })
_sym_db.RegisterMessage(VodGetAllPlayInfoRequest)

VodGetPlayInfoRequest = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetPlayInfoRequest)
  })
_sym_db.RegisterMessage(VodGetPlayInfoRequest)

VodGetPrivateDrmPlayAuthRequest = _reflection.GeneratedProtocolMessageType('VodGetPrivateDrmPlayAuthRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPRIVATEDRMPLAYAUTHREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetPrivateDrmPlayAuthRequest)
  })
_sym_db.RegisterMessage(VodGetPrivateDrmPlayAuthRequest)

VodGetHlsDecryptionKeyRequest = _reflection.GeneratedProtocolMessageType('VodGetHlsDecryptionKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETHLSDECRYPTIONKEYREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetHlsDecryptionKeyRequest)
  })
_sym_db.RegisterMessage(VodGetHlsDecryptionKeyRequest)

VodGetPlayInfoWithLiveTimeShiftSceneRequest = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoWithLiveTimeShiftSceneRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOWITHLIVETIMESHIFTSCENEREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetPlayInfoWithLiveTimeShiftSceneRequest)
  })
_sym_db.RegisterMessage(VodGetPlayInfoWithLiveTimeShiftSceneRequest)

VodUrlUploadRequest = _reflection.GeneratedProtocolMessageType('VodUrlUploadRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUrlUploadRequest)
  })
_sym_db.RegisterMessage(VodUrlUploadRequest)

VodQueryUploadTaskInfoRequest = _reflection.GeneratedProtocolMessageType('VodQueryUploadTaskInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYUPLOADTASKINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodQueryUploadTaskInfoRequest)
  })
_sym_db.RegisterMessage(VodQueryUploadTaskInfoRequest)

VodApplyUploadInfoRequest = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodApplyUploadInfoRequest)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoRequest)

VodUploadMediaRequest = _reflection.GeneratedProtocolMessageType('VodUploadMediaRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADMEDIAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUploadMediaRequest)
  })
_sym_db.RegisterMessage(VodUploadMediaRequest)

VodUploadMaterialRequest = _reflection.GeneratedProtocolMessageType('VodUploadMaterialRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADMATERIALREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUploadMaterialRequest)
  })
_sym_db.RegisterMessage(VodUploadMaterialRequest)

VodCommitUploadInfoRequest = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCommitUploadInfoRequest)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoRequest)

VodUrlUploadJsonRequest = _reflection.GeneratedProtocolMessageType('VodUrlUploadJsonRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADJSONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUrlUploadJsonRequest)
  })
_sym_db.RegisterMessage(VodUrlUploadJsonRequest)

VodGetRecommendedPosterRequest = _reflection.GeneratedProtocolMessageType('VodGetRecommendedPosterRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETRECOMMENDEDPOSTERREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetRecommendedPosterRequest)
  })
_sym_db.RegisterMessage(VodGetRecommendedPosterRequest)

VodUpdateMediaPublishStatusRequest = _reflection.GeneratedProtocolMessageType('VodUpdateMediaPublishStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAPUBLISHSTATUSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateMediaPublishStatusRequest)
  })
_sym_db.RegisterMessage(VodUpdateMediaPublishStatusRequest)

VodUpdateMediaInfoRequest = _reflection.GeneratedProtocolMessageType('VodUpdateMediaInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateMediaInfoRequest)
  })
_sym_db.RegisterMessage(VodUpdateMediaInfoRequest)

VodGetMediaInfosRequest = _reflection.GeneratedProtocolMessageType('VodGetMediaInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIAINFOSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetMediaInfosRequest)
  })
_sym_db.RegisterMessage(VodGetMediaInfosRequest)

VodDeleteMediaRequest = _reflection.GeneratedProtocolMessageType('VodDeleteMediaRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEMEDIAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDeleteMediaRequest)
  })
_sym_db.RegisterMessage(VodDeleteMediaRequest)

VodDeleteTranscodesRequest = _reflection.GeneratedProtocolMessageType('VodDeleteTranscodesRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETETRANSCODESREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDeleteTranscodesRequest)
  })
_sym_db.RegisterMessage(VodDeleteTranscodesRequest)

VodGetMediaListRequest = _reflection.GeneratedProtocolMessageType('VodGetMediaListRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIALISTREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetMediaListRequest)
  })
_sym_db.RegisterMessage(VodGetMediaListRequest)

VodGetSubtitleInfoListRequest = _reflection.GeneratedProtocolMessageType('VodGetSubtitleInfoListRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSUBTITLEINFOLISTREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetSubtitleInfoListRequest)
  })
_sym_db.RegisterMessage(VodGetSubtitleInfoListRequest)

VodUpdateSubtitleStatusRequest = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLESTATUSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateSubtitleStatusRequest)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleStatusRequest)

VodUpdateSubtitleInfoRequest = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLEINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateSubtitleInfoRequest)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleInfoRequest)

VodGetAuditFramesForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetAuditFramesForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDITFRAMESFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAuditFramesForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetAuditFramesForAuditRequest)

VodGetMLFramesForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetMLFramesForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMLFRAMESFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetMLFramesForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetMLFramesForAuditRequest)

VodGetBetterFramesForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetBetterFramesForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETBETTERFRAMESFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetBetterFramesForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetBetterFramesForAuditRequest)

VodGetAudioInfoForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetAudioInfoForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOINFOFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAudioInfoForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetAudioInfoForAuditRequest)

VodGetAutomaticSpeechRecognitionForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetAutomaticSpeechRecognitionForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAutomaticSpeechRecognitionForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetAutomaticSpeechRecognitionForAuditRequest)

VodGetAudioEventDetectionForAuditRequest = _reflection.GeneratedProtocolMessageType('VodGetAudioEventDetectionForAuditRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOEVENTDETECTIONFORAUDITREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetAudioEventDetectionForAuditRequest)
  })
_sym_db.RegisterMessage(VodGetAudioEventDetectionForAuditRequest)

VodCreateVideoClassificationRequest = _reflection.GeneratedProtocolMessageType('VodCreateVideoClassificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEVIDEOCLASSIFICATIONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCreateVideoClassificationRequest)
  })
_sym_db.RegisterMessage(VodCreateVideoClassificationRequest)

VodUpdateVideoClassificationRequest = _reflection.GeneratedProtocolMessageType('VodUpdateVideoClassificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEVIDEOCLASSIFICATIONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateVideoClassificationRequest)
  })
_sym_db.RegisterMessage(VodUpdateVideoClassificationRequest)

VodDeleteVideoClassificationRequest = _reflection.GeneratedProtocolMessageType('VodDeleteVideoClassificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEVIDEOCLASSIFICATIONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDeleteVideoClassificationRequest)
  })
_sym_db.RegisterMessage(VodDeleteVideoClassificationRequest)

VodListVideoClassificationsRequest = _reflection.GeneratedProtocolMessageType('VodListVideoClassificationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTVIDEOCLASSIFICATIONSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListVideoClassificationsRequest)
  })
_sym_db.RegisterMessage(VodListVideoClassificationsRequest)

VodListSnapshotsRequest = _reflection.GeneratedProtocolMessageType('VodListSnapshotsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSNAPSHOTSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListSnapshotsRequest)
  })
_sym_db.RegisterMessage(VodListSnapshotsRequest)

VodStartWorkflowRequest = _reflection.GeneratedProtocolMessageType('VodStartWorkflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODSTARTWORKFLOWREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodStartWorkflowRequest)
  })
_sym_db.RegisterMessage(VodStartWorkflowRequest)

VodRetrieveTranscodeResultRequest = _reflection.GeneratedProtocolMessageType('VodRetrieveTranscodeResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODRETRIEVETRANSCODERESULTREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodRetrieveTranscodeResultRequest)
  })
_sym_db.RegisterMessage(VodRetrieveTranscodeResultRequest)

VodCreateSpaceRequest = _reflection.GeneratedProtocolMessageType('VodCreateSpaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATESPACEREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCreateSpaceRequest)
  })
_sym_db.RegisterMessage(VodCreateSpaceRequest)

VodGetSpaceDetailRequest = _reflection.GeneratedProtocolMessageType('VodGetSpaceDetailRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSPACEDETAILREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetSpaceDetailRequest)
  })
_sym_db.RegisterMessage(VodGetSpaceDetailRequest)

VodListSpaceRequest = _reflection.GeneratedProtocolMessageType('VodListSpaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSPACEREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListSpaceRequest)
  })
_sym_db.RegisterMessage(VodListSpaceRequest)

VodUpdateSpaceRequest = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACEREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateSpaceRequest)
  })
_sym_db.RegisterMessage(VodUpdateSpaceRequest)

VodUpdateSpaceUploadConfigRequest = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceUploadConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACEUPLOADCONFIGREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodUpdateSpaceUploadConfigRequest)
  })
_sym_db.RegisterMessage(VodUpdateSpaceUploadConfigRequest)

VodListDomainRequest = _reflection.GeneratedProtocolMessageType('VodListDomainRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTDOMAINREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListDomainRequest)
  })
_sym_db.RegisterMessage(VodListDomainRequest)

VodCreateCdnRefreshTaskRequest = _reflection.GeneratedProtocolMessageType('VodCreateCdnRefreshTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNREFRESHTASKREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCreateCdnRefreshTaskRequest)
  })
_sym_db.RegisterMessage(VodCreateCdnRefreshTaskRequest)

VodCreateCdnPreloadTaskRequest = _reflection.GeneratedProtocolMessageType('VodCreateCdnPreloadTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNPRELOADTASKREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodCreateCdnPreloadTaskRequest)
  })
_sym_db.RegisterMessage(VodCreateCdnPreloadTaskRequest)

VodListCdnTasksRequest = _reflection.GeneratedProtocolMessageType('VodListCdnTasksRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTASKSREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnTasksRequest)
  })
_sym_db.RegisterMessage(VodListCdnTasksRequest)

VodListCdnAccessLogRequest = _reflection.GeneratedProtocolMessageType('VodListCdnAccessLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNACCESSLOGREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnAccessLogRequest)
  })
_sym_db.RegisterMessage(VodListCdnAccessLogRequest)

VodListCdnTopAccessUrlRequest = _reflection.GeneratedProtocolMessageType('VodListCdnTopAccessUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTOPACCESSURLREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnTopAccessUrlRequest)
  })
_sym_db.RegisterMessage(VodListCdnTopAccessUrlRequest)

VodDescribeVodDomainBandwidthDataRequest = _reflection.GeneratedProtocolMessageType('VodDescribeVodDomainBandwidthDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODDOMAINBANDWIDTHDATAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDescribeVodDomainBandwidthDataRequest)
  })
_sym_db.RegisterMessage(VodDescribeVodDomainBandwidthDataRequest)

VodListCdnUsageDataRequest = _reflection.GeneratedProtocolMessageType('VodListCdnUsageDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNUSAGEDATAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnUsageDataRequest)
  })
_sym_db.RegisterMessage(VodListCdnUsageDataRequest)

VodListCdnStatusDataRequest = _reflection.GeneratedProtocolMessageType('VodListCdnStatusDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNSTATUSDATAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnStatusDataRequest)
  })
_sym_db.RegisterMessage(VodListCdnStatusDataRequest)

VodDescribeIPInfoRequest = _reflection.GeneratedProtocolMessageType('VodDescribeIPInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEIPINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodDescribeIPInfoRequest)
  })
_sym_db.RegisterMessage(VodDescribeIPInfoRequest)

VodListCdnPvDataRequest = _reflection.GeneratedProtocolMessageType('VodListCdnPvDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNPVDATAREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodListCdnPvDataRequest)
  })
_sym_db.RegisterMessage(VodListCdnPvDataRequest)

VodAddCallbackSubscriptionRequest = _reflection.GeneratedProtocolMessageType('VodAddCallbackSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODADDCALLBACKSUBSCRIPTIONREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodAddCallbackSubscriptionRequest)
  })
_sym_db.RegisterMessage(VodAddCallbackSubscriptionRequest)

VodSetCallbackEventRequest = _reflection.GeneratedProtocolMessageType('VodSetCallbackEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODSETCALLBACKEVENTREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodSetCallbackEventRequest)
  })
_sym_db.RegisterMessage(VodSetCallbackEventRequest)

VodGetSmartStrategyLitePlayInfoRequest = _reflection.GeneratedProtocolMessageType('VodGetSmartStrategyLitePlayInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSMARTSTRATEGYLITEPLAYINFOREQUEST,
  '__module__' : 'vod.request.request_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Request.VodGetSmartStrategyLitePlayInfoRequest)
  })
_sym_db.RegisterMessage(VodGetSmartStrategyLitePlayInfoRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.volcengine.service.vod.model.requestB\nVodRequestP\001Z@github.com/volcengine/volc-sdk-golang/service/vod/models/request\240\001\001\330\001\001\312\002\037Volc\\Service\\Vod\\Models\\Request\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETALLPLAYINFOREQUEST._serialized_start=161
  _VODGETALLPLAYINFOREQUEST._serialized_end=549
  _VODGETPLAYINFOREQUEST._serialized_start=552
  _VODGETPLAYINFOREQUEST._serialized_end=872
  _VODGETPRIVATEDRMPLAYAUTHREQUEST._serialized_start=874
  _VODGETPRIVATEDRMPLAYAUTHREQUEST._serialized_end=977
  _VODGETHLSDECRYPTIONKEYREQUEST._serialized_start=979
  _VODGETHLSDECRYPTIONKEYREQUEST._serialized_end=1060
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENEREQUEST._serialized_start=1063
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENEREQUEST._serialized_end=1215
  _VODURLUPLOADREQUEST._serialized_start=1217
  _VODURLUPLOADREQUEST._serialized_end=1326
  _VODQUERYUPLOADTASKINFOREQUEST._serialized_start=1328
  _VODQUERYUPLOADTASKINFOREQUEST._serialized_end=1375
  _VODAPPLYUPLOADINFOREQUEST._serialized_start=1377
  _VODAPPLYUPLOADINFOREQUEST._serialized_end=1497
  _VODUPLOADMEDIAREQUEST._serialized_start=1499
  _VODUPLOADMEDIAREQUEST._serialized_end=1618
  _VODUPLOADMATERIALREQUEST._serialized_start=1621
  _VODUPLOADMATERIALREQUEST._serialized_end=1761
  _VODCOMMITUPLOADINFOREQUEST._serialized_start=1763
  _VODCOMMITUPLOADINFOREQUEST._serialized_end=1871
  _VODURLUPLOADJSONREQUEST._serialized_start=1873
  _VODURLUPLOADJSONREQUEST._serialized_end=1934
  _VODGETRECOMMENDEDPOSTERREQUEST._serialized_start=1936
  _VODGETRECOMMENDEDPOSTERREQUEST._serialized_end=1982
  _VODUPDATEMEDIAPUBLISHSTATUSREQUEST._serialized_start=1984
  _VODUPDATEMEDIAPUBLISHSTATUSREQUEST._serialized_end=2049
  _VODUPDATEMEDIAINFOREQUEST._serialized_start=2052
  _VODUPDATEMEDIAINFOREQUEST._serialized_end=2336
  _VODGETMEDIAINFOSREQUEST._serialized_start=2338
  _VODGETMEDIAINFOSREQUEST._serialized_end=2377
  _VODDELETEMEDIAREQUEST._serialized_start=2379
  _VODDELETEMEDIAREQUEST._serialized_end=2438
  _VODDELETETRANSCODESREQUEST._serialized_start=2440
  _VODDELETETRANSCODESREQUEST._serialized_end=2520
  _VODGETMEDIALISTREQUEST._serialized_start=2523
  _VODGETMEDIALISTREQUEST._serialized_end=2721
  _VODGETSUBTITLEINFOLISTREQUEST._serialized_start=2724
  _VODGETSUBTITLEINFOLISTREQUEST._serialized_end=2954
  _VODUPDATESUBTITLESTATUSREQUEST._serialized_start=2956
  _VODUPDATESUBTITLESTATUSREQUEST._serialized_end=3070
  _VODUPDATESUBTITLEINFOREQUEST._serialized_start=3073
  _VODUPDATESUBTITLEINFOREQUEST._serialized_end=3254
  _VODGETAUDITFRAMESFORAUDITREQUEST._serialized_start=3256
  _VODGETAUDITFRAMESFORAUDITREQUEST._serialized_end=3375
  _VODGETMLFRAMESFORAUDITREQUEST._serialized_start=3378
  _VODGETMLFRAMESFORAUDITREQUEST._serialized_end=3667
  _VODGETBETTERFRAMESFORAUDITREQUEST._serialized_start=3669
  _VODGETBETTERFRAMESFORAUDITREQUEST._serialized_end=3754
  _VODGETAUDIOINFOFORAUDITREQUEST._serialized_start=3756
  _VODGETAUDIOINFOFORAUDITREQUEST._serialized_end=3819
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITREQUEST._serialized_start=3821
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITREQUEST._serialized_end=3901
  _VODGETAUDIOEVENTDETECTIONFORAUDITREQUEST._serialized_start=3903
  _VODGETAUDIOEVENTDETECTIONFORAUDITREQUEST._serialized_end=3976
  _VODCREATEVIDEOCLASSIFICATIONREQUEST._serialized_start=3978
  _VODCREATEVIDEOCLASSIFICATIONREQUEST._serialized_end=4091
  _VODUPDATEVIDEOCLASSIFICATIONREQUEST._serialized_start=4093
  _VODUPDATEVIDEOCLASSIFICATIONREQUEST._serialized_end=4199
  _VODDELETEVIDEOCLASSIFICATIONREQUEST._serialized_start=4201
  _VODDELETEVIDEOCLASSIFICATIONREQUEST._serialized_end=4283
  _VODLISTVIDEOCLASSIFICATIONSREQUEST._serialized_start=4285
  _VODLISTVIDEOCLASSIFICATIONSREQUEST._serialized_end=4366
  _VODLISTSNAPSHOTSREQUEST._serialized_start=4368
  _VODLISTSNAPSHOTSREQUEST._serialized_end=4406
  _VODSTARTWORKFLOWREQUEST._serialized_start=4409
  _VODSTARTWORKFLOWREQUEST._serialized_end=4597
  _VODRETRIEVETRANSCODERESULTREQUEST._serialized_start=4599
  _VODRETRIEVETRANSCODERESULTREQUEST._serialized_end=4667
  _VODCREATESPACEREQUEST._serialized_start=4669
  _VODCREATESPACEREQUEST._serialized_end=4787
  _VODGETSPACEDETAILREQUEST._serialized_start=4789
  _VODGETSPACEDETAILREQUEST._serialized_end=4834
  _VODLISTSPACEREQUEST._serialized_start=4836
  _VODLISTSPACEREQUEST._serialized_end=4888
  _VODUPDATESPACEREQUEST._serialized_start=4890
  _VODUPDATESPACEREQUEST._serialized_end=5007
  _VODUPDATESPACEUPLOADCONFIGREQUEST._serialized_start=5009
  _VODUPDATESPACEUPLOADCONFIGREQUEST._serialized_end=5103
  _VODLISTDOMAINREQUEST._serialized_start=5105
  _VODLISTDOMAINREQUEST._serialized_end=5146
  _VODCREATECDNREFRESHTASKREQUEST._serialized_start=5148
  _VODCREATECDNREFRESHTASKREQUEST._serialized_end=5227
  _VODCREATECDNPRELOADTASKREQUEST._serialized_start=5229
  _VODCREATECDNPRELOADTASKREQUEST._serialized_end=5294
  _VODLISTCDNTASKSREQUEST._serialized_start=5297
  _VODLISTCDNTASKSREQUEST._serialized_end=5491
  _VODLISTCDNACCESSLOGREQUEST._serialized_start=5493
  _VODLISTCDNACCESSLOGREQUEST._serialized_end=5603
  _VODLISTCDNTOPACCESSURLREQUEST._serialized_start=5605
  _VODLISTCDNTOPACCESSURLREQUEST._serialized_end=5717
  _VODDESCRIBEVODDOMAINBANDWIDTHDATAREQUEST._serialized_start=5720
  _VODDESCRIBEVODDOMAINBANDWIDTHDATAREQUEST._serialized_end=5862
  _VODLISTCDNUSAGEDATAREQUEST._serialized_start=5865
  _VODLISTCDNUSAGEDATAREQUEST._serialized_end=6008
  _VODLISTCDNSTATUSDATAREQUEST._serialized_start=6011
  _VODLISTCDNSTATUSDATAREQUEST._serialized_end=6155
  _VODDESCRIBEIPINFOREQUEST._serialized_start=6157
  _VODDESCRIBEIPINFOREQUEST._serialized_end=6196
  _VODLISTCDNPVDATAREQUEST._serialized_start=6198
  _VODLISTCDNPVDATAREQUEST._serialized_end=6322
  _VODADDCALLBACKSUBSCRIPTIONREQUEST._serialized_start=6324
  _VODADDCALLBACKSUBSCRIPTIONREQUEST._serialized_end=6391
  _VODSETCALLBACKEVENTREQUEST._serialized_start=6393
  _VODSETCALLBACKEVENTREQUEST._serialized_end=6497
  _VODGETSMARTSTRATEGYLITEPLAYINFOREQUEST._serialized_start=6500
  _VODGETSMARTSTRATEGYLITEPLAYINFOREQUEST._serialized_end=6744
# @@protoc_insertion_point(module_scope)
