# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvod/business/vod_common.proto\x12\x1eVolcengine.Vod.Models.Business\"\x85\x02\n\rVodSourceInfo\x12\x0e\n\x06\x46ileId\x18\x01 \x01(\t\x12\x0b\n\x03Md5\x18\x02 \x01(\t\x12\x10\n\x08\x46ileType\x18\x03 \x01(\t\x12\r\n\x05\x43odec\x18\x04 \x01(\t\x12\x0e\n\x06Height\x18\x05 \x01(\x05\x12\r\n\x05Width\x18\x06 \x01(\x05\x12\x0e\n\x06\x46ormat\x18\x07 \x01(\t\x12\x10\n\x08\x44uration\x18\x08 \x01(\x02\x12\x0c\n\x04Size\x18\t \x01(\x01\x12\x10\n\x08StoreUri\x18\n \x01(\t\x12\x12\n\nDefinition\x18\x0b \x01(\t\x12\x0f\n\x07\x42itrate\x18\x0c \x01(\x05\x12\x0b\n\x03\x46ps\x18\r \x01(\x02\x12\x12\n\nCreateTime\x18\x0e \x01(\t\x12\x0f\n\x07Quality\x18\x0f \x01(\t\"k\n\x12VodAudioStreamMeta\x12\r\n\x05\x43odec\x18\x01 \x01(\t\x12\x10\n\x08\x44uration\x18\x02 \x01(\x02\x12\x12\n\nSampleRate\x18\x03 \x01(\x05\x12\x0f\n\x07\x42itrate\x18\x04 \x01(\x05\x12\x0f\n\x07Quality\x18\x05 \x01(\t\"\x86\x01\n\x12VodVideoStreamMeta\x12\r\n\x05\x43odec\x18\x01 \x01(\t\x12\x0e\n\x06Height\x18\x02 \x01(\x05\x12\r\n\x05Width\x18\x03 \x01(\x05\x12\x10\n\x08\x44uration\x18\x04 \x01(\x02\x12\x12\n\nDefinition\x18\x05 \x01(\t\x12\x0f\n\x07\x42itrate\x18\x06 \x01(\x05\x12\x0b\n\x03\x46ps\x18\x07 \x01(\x02\"\xd4\x02\n\x10VodTranscodeInfo\x12\x0e\n\x06\x46ileId\x18\x01 \x01(\t\x12\x0b\n\x03Md5\x18\x02 \x01(\t\x12\x10\n\x08\x46ileType\x18\x03 \x01(\t\x12\x10\n\x08LogoType\x18\x04 \x01(\t\x12\x0f\n\x07\x45ncrypt\x18\x05 \x01(\x08\x12\x0e\n\x06\x46ormat\x18\x06 \x01(\t\x12\x10\n\x08\x44uration\x18\x07 \x01(\x02\x12\x0c\n\x04Size\x18\x08 \x01(\x01\x12\x10\n\x08StoreUri\x18\t \x01(\t\x12K\n\x0fVideoStreamMeta\x18\n \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodVideoStreamMeta\x12K\n\x0f\x41udioStreamMeta\x18\x0b \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodAudioStreamMeta\x12\x12\n\nCreateTime\x18\x0c \x01(\t\"S\n\x0fVodAdaptiveInfo\x12\x13\n\x0bMainPlayUrl\x18\x01 \x01(\t\x12\x15\n\rBackupPlayUrl\x18\x02 \x01(\t\x12\x14\n\x0c\x41\x64\x61ptiveType\x18\x03 \x01(\t\"\xa4\x03\n\x0bVodPlayInfo\x12\x0e\n\x06\x46ileId\x18\x01 \x01(\t\x12\x0b\n\x03Md5\x18\x02 \x01(\t\x12\x10\n\x08\x46ileType\x18\x03 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x04 \x01(\t\x12\r\n\x05\x43odec\x18\x05 \x01(\t\x12\x12\n\nDefinition\x18\x06 \x01(\t\x12\x13\n\x0bMainPlayUrl\x18\x07 \x01(\t\x12\x15\n\rBackupPlayUrl\x18\x08 \x01(\t\x12\x0f\n\x07\x42itrate\x18\t \x01(\x05\x12\r\n\x05Width\x18\n \x01(\x05\x12\x0e\n\x06Height\x18\x0b \x01(\x05\x12\x0c\n\x04Size\x18\x0c \x01(\x01\x12\x11\n\tCheckInfo\x18\r \x01(\t\x12\x12\n\nIndexRange\x18\x0e \x01(\t\x12\x11\n\tInitRange\x18\x0f \x01(\t\x12\x10\n\x08PlayAuth\x18\x10 \x01(\t\x12\x12\n\nPlayAuthId\x18\x11 \x01(\t\x12\x10\n\x08LogoType\x18\x12 \x01(\t\x12\x0f\n\x07Quality\x18\x13 \x01(\t\x12\x19\n\x11\x42\x61rrageMaskOffset\x18\x14 \x01(\t\x12\x10\n\x08\x44uration\x18\x15 \x01(\x02\x12\x19\n\x11KeyFrameAlignment\x18\x16 \x01(\t\"\xa0\x01\n\x0cVodThumbInfo\x12\x12\n\nCaptureNum\x18\x01 \x01(\x05\x12\x11\n\tStoreUrls\x18\x02 \x03(\t\x12\x11\n\tCellWidth\x18\x03 \x01(\x05\x12\x12\n\nCellHeight\x18\x04 \x01(\x05\x12\x0f\n\x07ImgXLen\x18\x05 \x01(\x05\x12\x0f\n\x07ImgYLen\x18\x06 \x01(\x05\x12\x10\n\x08Interval\x18\x07 \x01(\x01\x12\x0e\n\x06\x46ormat\x18\x08 \x01(\t\"\x80\x02\n\x0fVodSubtitleInfo\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06\x46ileId\x18\x02 \x01(\t\x12\x10\n\x08Language\x18\x03 \x01(\t\x12\x12\n\nLanguageId\x18\x04 \x01(\x05\x12\x0e\n\x06\x46ormat\x18\x05 \x01(\t\x12\x12\n\nSubtitleId\x18\x06 \x01(\t\x12\r\n\x05Title\x18\x07 \x01(\t\x12\x0b\n\x03Tag\x18\x08 \x01(\t\x12\x0e\n\x06Status\x18\t \x01(\t\x12\x0e\n\x06Source\x18\n \x01(\t\x12\x10\n\x08StoreUri\x18\x0b \x01(\t\x12\x13\n\x0bSubtitleUrl\x18\x0c \x01(\t\x12\x12\n\nCreateTime\x18\r \x01(\t\x12\x0f\n\x07Version\x18\x0e \x01(\t\"A\n\x13VodCommonConfigInfo\x12\x0e\n\x06Module\x18\x01 \x01(\t\x12\x0b\n\x03Key\x18\x02 \x01(\t\x12\r\n\x05Value\x18\x03 \x01(\t\"\x8e\x04\n\x10VodPlayInfoModel\x12H\n\x07Version\x18\n \x01(\x0e\x32\x37.Volcengine.Vod.Models.Business.VodPlayInfoModelVersion\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06Status\x18\x02 \x01(\x05\x12\x11\n\tPosterUrl\x18\x03 \x01(\t\x12\x10\n\x08\x44uration\x18\x04 \x01(\x02\x12\x10\n\x08\x46ileType\x18\x05 \x01(\t\x12\x16\n\x0e\x45nableAdaptive\x18\x06 \x01(\x08\x12\x12\n\nTotalCount\x18\x07 \x01(\x05\x12\x45\n\x0c\x41\x64\x61ptiveInfo\x18\x08 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.VodAdaptiveInfo\x12\x41\n\x0cPlayInfoList\x18\t \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodPlayInfo\x12\x43\n\rThumbInfoList\x18\x0b \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodThumbInfo\x12\x16\n\x0e\x42\x61rrageMaskUrl\x18\x0c \x01(\t\x12I\n\x10SubtitleInfoList\x18\r \x03(\x0b\x32/.Volcengine.Vod.Models.Business.VodSubtitleInfo\",\n\x08VodPoint\x12\x11\n\tTimestamp\x18\x01 \x01(\x01\x12\r\n\x05Value\x18\x02 \x01(\x01\"\x96\x01\n\x14VodAllPlayInfoResult\x12T\n\x17VodAllPlayInfoModelList\x18\x01 \x03(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodAllPlayInfoModel\x12\x12\n\nTotalCount\x18\x02 \x01(\x05\x12\x14\n\x0cNotFoundVids\x18\x03 \x03(\t\"\xf6\x03\n\x13VodAllPlayInfoModel\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06Status\x18\x02 \x01(\x05\x12\x11\n\tPosterUrl\x18\x03 \x01(\t\x12\x12\n\nTotalCount\x18\x04 \x01(\x05\x12\x16\n\x0e\x45nableAdaptive\x18\x05 \x01(\x08\x12I\n\x14VodTranscodePlayInfo\x18\x06 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodPlayInfo\x12\x46\n\x11VodSourcePlayInfo\x18\x07 \x01(\x0b\x32+.Volcengine.Vod.Models.Business.VodPlayInfo\x12H\n\x07Version\x18\x08 \x01(\x0e\x32\x37.Volcengine.Vod.Models.Business.VodPlayInfoModelVersion\x12\x43\n\rThumbInfoList\x18\t \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodThumbInfo\x12\x16\n\x0e\x42\x61rrageMaskUrl\x18\n \x01(\t\x12I\n\x10SubtitleInfoList\x18\x0b \x03(\x0b\x32/.Volcengine.Vod.Models.Business.VodSubtitleInfo*\xd6\x01\n\x17VodPlayInfoModelVersion\x12$\n UndefinedVodPlayInfoModelVersion\x10\x00\x12%\n!InternalV1VodPlayInfoModelVersion\x10\x01\x12%\n!InternalV2VodPlayInfoModelVersion\x10\x02\x12%\n!InternalV3VodPlayInfoModelVersion\x10\x03\x12 \n\x1cToBV1VodPlayInfoModelVersion\x10\x04\x42\xcd\x01\n)com.volcengine.service.vod.model.businessB\tVodCommonP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_VODPLAYINFOMODELVERSION = DESCRIPTOR.enum_types_by_name['VodPlayInfoModelVersion']
VodPlayInfoModelVersion = enum_type_wrapper.EnumTypeWrapper(_VODPLAYINFOMODELVERSION)
UndefinedVodPlayInfoModelVersion = 0
InternalV1VodPlayInfoModelVersion = 1
InternalV2VodPlayInfoModelVersion = 2
InternalV3VodPlayInfoModelVersion = 3
ToBV1VodPlayInfoModelVersion = 4


_VODSOURCEINFO = DESCRIPTOR.message_types_by_name['VodSourceInfo']
_VODAUDIOSTREAMMETA = DESCRIPTOR.message_types_by_name['VodAudioStreamMeta']
_VODVIDEOSTREAMMETA = DESCRIPTOR.message_types_by_name['VodVideoStreamMeta']
_VODTRANSCODEINFO = DESCRIPTOR.message_types_by_name['VodTranscodeInfo']
_VODADAPTIVEINFO = DESCRIPTOR.message_types_by_name['VodAdaptiveInfo']
_VODPLAYINFO = DESCRIPTOR.message_types_by_name['VodPlayInfo']
_VODTHUMBINFO = DESCRIPTOR.message_types_by_name['VodThumbInfo']
_VODSUBTITLEINFO = DESCRIPTOR.message_types_by_name['VodSubtitleInfo']
_VODCOMMONCONFIGINFO = DESCRIPTOR.message_types_by_name['VodCommonConfigInfo']
_VODPLAYINFOMODEL = DESCRIPTOR.message_types_by_name['VodPlayInfoModel']
_VODPOINT = DESCRIPTOR.message_types_by_name['VodPoint']
_VODALLPLAYINFORESULT = DESCRIPTOR.message_types_by_name['VodAllPlayInfoResult']
_VODALLPLAYINFOMODEL = DESCRIPTOR.message_types_by_name['VodAllPlayInfoModel']
VodSourceInfo = _reflection.GeneratedProtocolMessageType('VodSourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODSOURCEINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSourceInfo)
  })
_sym_db.RegisterMessage(VodSourceInfo)

VodAudioStreamMeta = _reflection.GeneratedProtocolMessageType('VodAudioStreamMeta', (_message.Message,), {
  'DESCRIPTOR' : _VODAUDIOSTREAMMETA,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAudioStreamMeta)
  })
_sym_db.RegisterMessage(VodAudioStreamMeta)

VodVideoStreamMeta = _reflection.GeneratedProtocolMessageType('VodVideoStreamMeta', (_message.Message,), {
  'DESCRIPTOR' : _VODVIDEOSTREAMMETA,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodVideoStreamMeta)
  })
_sym_db.RegisterMessage(VodVideoStreamMeta)

VodTranscodeInfo = _reflection.GeneratedProtocolMessageType('VodTranscodeInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODTRANSCODEINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodTranscodeInfo)
  })
_sym_db.RegisterMessage(VodTranscodeInfo)

VodAdaptiveInfo = _reflection.GeneratedProtocolMessageType('VodAdaptiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODADAPTIVEINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAdaptiveInfo)
  })
_sym_db.RegisterMessage(VodAdaptiveInfo)

VodPlayInfo = _reflection.GeneratedProtocolMessageType('VodPlayInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODPLAYINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodPlayInfo)
  })
_sym_db.RegisterMessage(VodPlayInfo)

VodThumbInfo = _reflection.GeneratedProtocolMessageType('VodThumbInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODTHUMBINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodThumbInfo)
  })
_sym_db.RegisterMessage(VodThumbInfo)

VodSubtitleInfo = _reflection.GeneratedProtocolMessageType('VodSubtitleInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODSUBTITLEINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSubtitleInfo)
  })
_sym_db.RegisterMessage(VodSubtitleInfo)

VodCommonConfigInfo = _reflection.GeneratedProtocolMessageType('VodCommonConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMONCONFIGINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommonConfigInfo)
  })
_sym_db.RegisterMessage(VodCommonConfigInfo)

VodPlayInfoModel = _reflection.GeneratedProtocolMessageType('VodPlayInfoModel', (_message.Message,), {
  'DESCRIPTOR' : _VODPLAYINFOMODEL,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodPlayInfoModel)
  })
_sym_db.RegisterMessage(VodPlayInfoModel)

VodPoint = _reflection.GeneratedProtocolMessageType('VodPoint', (_message.Message,), {
  'DESCRIPTOR' : _VODPOINT,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodPoint)
  })
_sym_db.RegisterMessage(VodPoint)

VodAllPlayInfoResult = _reflection.GeneratedProtocolMessageType('VodAllPlayInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODALLPLAYINFORESULT,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAllPlayInfoResult)
  })
_sym_db.RegisterMessage(VodAllPlayInfoResult)

VodAllPlayInfoModel = _reflection.GeneratedProtocolMessageType('VodAllPlayInfoModel', (_message.Message,), {
  'DESCRIPTOR' : _VODALLPLAYINFOMODEL,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAllPlayInfoModel)
  })
_sym_db.RegisterMessage(VodAllPlayInfoModel)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\tVodCommonP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODPLAYINFOMODELVERSION._serialized_start=3149
  _VODPLAYINFOMODELVERSION._serialized_end=3363
  _VODSOURCEINFO._serialized_start=66
  _VODSOURCEINFO._serialized_end=327
  _VODAUDIOSTREAMMETA._serialized_start=329
  _VODAUDIOSTREAMMETA._serialized_end=436
  _VODVIDEOSTREAMMETA._serialized_start=439
  _VODVIDEOSTREAMMETA._serialized_end=573
  _VODTRANSCODEINFO._serialized_start=576
  _VODTRANSCODEINFO._serialized_end=916
  _VODADAPTIVEINFO._serialized_start=918
  _VODADAPTIVEINFO._serialized_end=1001
  _VODPLAYINFO._serialized_start=1004
  _VODPLAYINFO._serialized_end=1424
  _VODTHUMBINFO._serialized_start=1427
  _VODTHUMBINFO._serialized_end=1587
  _VODSUBTITLEINFO._serialized_start=1590
  _VODSUBTITLEINFO._serialized_end=1846
  _VODCOMMONCONFIGINFO._serialized_start=1848
  _VODCOMMONCONFIGINFO._serialized_end=1913
  _VODPLAYINFOMODEL._serialized_start=1916
  _VODPLAYINFOMODEL._serialized_end=2442
  _VODPOINT._serialized_start=2444
  _VODPOINT._serialized_end=2488
  _VODALLPLAYINFORESULT._serialized_start=2491
  _VODALLPLAYINFORESULT._serialized_end=2641
  _VODALLPLAYINFOMODEL._serialized_start=2644
  _VODALLPLAYINFOMODEL._serialized_end=3146
# @@protoc_insertion_point(module_scope)
