# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base/base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62\x61se/base.proto\x12\x1bVolcengine.Base.Models.Base\x1a google/protobuf/descriptor.proto\"\xa2\x01\n\x10ResponseMetadata\x12\x11\n\tRequestId\x18\x01 \x01(\t\x12\x0e\n\x06\x41\x63tion\x18\x02 \x01(\t\x12\x0f\n\x07Version\x18\x03 \x01(\t\x12\x0f\n\x07Service\x18\x04 \x01(\t\x12\x0e\n\x06Region\x18\x05 \x01(\t\x12\x39\n\x05\x45rror\x18\x06 \x01(\x0b\x32*.Volcengine.Base.Models.Base.ResponseError\".\n\rResponseError\x12\x0c\n\x04\x43ode\x18\x01 \x01(\t\x12\x0f\n\x07Message\x18\x02 \x01(\tB\xc0\x01\n&com.volcengine.service.base.model.baseB\x04\x42\x61seP\x01Z>github.com/volcengine/volc-sdk-golang/service/base/models/base\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02\x1dVolc\\Service\\Base\\Models\\Base\xe2\x02$Volc\\Service\\Base\\Models\\GPBMetadatab\x06proto3')



_RESPONSEMETADATA = DESCRIPTOR.message_types_by_name['ResponseMetadata']
_RESPONSEERROR = DESCRIPTOR.message_types_by_name['ResponseError']
ResponseMetadata = _reflection.GeneratedProtocolMessageType('ResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEMETADATA,
  '__module__' : 'base.base_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Base.Models.Base.ResponseMetadata)
  })
_sym_db.RegisterMessage(ResponseMetadata)

ResponseError = _reflection.GeneratedProtocolMessageType('ResponseError', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEERROR,
  '__module__' : 'base.base_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Base.Models.Base.ResponseError)
  })
_sym_db.RegisterMessage(ResponseError)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.volcengine.service.base.model.baseB\004BaseP\001Z>github.com/volcengine/volc-sdk-golang/service/base/models/base\240\001\001\330\001\001\302\002\000\312\002\035Volc\\Service\\Base\\Models\\Base\342\002$Volc\\Service\\Base\\Models\\GPBMetadata'
  _RESPONSEMETADATA._serialized_start=83
  _RESPONSEMETADATA._serialized_end=245
  _RESPONSEERROR._serialized_start=247
  _RESPONSEERROR._serialized_end=293
# @@protoc_insertion_point(module_scope)
