# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_smart_strategy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%vod/business/vod_smart_strategy.proto\x12\x1eVolcengine.Vod.Models.Business\x1a\x1dvod/business/vod_common.proto\"\xbb\x02\n%VodGetSmartStrategyLitePlayInfoResult\x12V\n\nStreamType\x18\x01 \x01(\x0e\x32\x42.Volcengine.Vod.Models.Business.VodSmartStrategyResponseStreamType\x12X\n\x0f\x44\x61taStoreStatus\x18\x02 \x01(\x0e\x32?.Volcengine.Vod.Models.Business.VodSmartStrategyDataStoreStatus\x12G\n\rPlayInfoModel\x18\x03 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodPlayInfoModel\x12\x17\n\x0fOriginalPlayUrl\x18\x04 \x01(\t*\x83\x02\n\"VodSmartStrategyResponseStreamType\x12/\n+UndefinedVodSmartStrategyResponseStreamType\x10\x00\x12\x34\n0OriginalStreamVodSmartStrategyResponseStreamType\x10\x01\x12:\n6StrategyEncodeStreamVodSmartStrategyResponseStreamType\x10\x02\x12:\n6FallbackEncodeStreamVodSmartStrategyResponseStreamType\x10\x03*\xe6\x01\n\x1fVodSmartStrategyDataStoreStatus\x12,\n(UndefinedVodSmartStrategyDataStoreStatus\x10\x00\x12+\n\'NotExistVodSmartStrategyDataStoreStatus\x10\x01\x12\x34\n0HasOriginalStreamVodSmartStrategyDataStoreStatus\x10\x02\x12\x32\n.HasEncodeStreamVodSmartStrategyDataStoreStatus\x10\x03\x42\xd4\x01\n)com.volcengine.service.vod.model.businessB\x10VodSmartStrategyP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_VODSMARTSTRATEGYRESPONSESTREAMTYPE = DESCRIPTOR.enum_types_by_name['VodSmartStrategyResponseStreamType']
VodSmartStrategyResponseStreamType = enum_type_wrapper.EnumTypeWrapper(_VODSMARTSTRATEGYRESPONSESTREAMTYPE)
_VODSMARTSTRATEGYDATASTORESTATUS = DESCRIPTOR.enum_types_by_name['VodSmartStrategyDataStoreStatus']
VodSmartStrategyDataStoreStatus = enum_type_wrapper.EnumTypeWrapper(_VODSMARTSTRATEGYDATASTORESTATUS)
UndefinedVodSmartStrategyResponseStreamType = 0
OriginalStreamVodSmartStrategyResponseStreamType = 1
StrategyEncodeStreamVodSmartStrategyResponseStreamType = 2
FallbackEncodeStreamVodSmartStrategyResponseStreamType = 3
UndefinedVodSmartStrategyDataStoreStatus = 0
NotExistVodSmartStrategyDataStoreStatus = 1
HasOriginalStreamVodSmartStrategyDataStoreStatus = 2
HasEncodeStreamVodSmartStrategyDataStoreStatus = 3


_VODGETSMARTSTRATEGYLITEPLAYINFORESULT = DESCRIPTOR.message_types_by_name['VodGetSmartStrategyLitePlayInfoResult']
VodGetSmartStrategyLitePlayInfoResult = _reflection.GeneratedProtocolMessageType('VodGetSmartStrategyLitePlayInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSMARTSTRATEGYLITEPLAYINFORESULT,
  '__module__' : 'vod.business.vod_smart_strategy_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetSmartStrategyLitePlayInfoResult)
  })
_sym_db.RegisterMessage(VodGetSmartStrategyLitePlayInfoResult)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\020VodSmartStrategyP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODSMARTSTRATEGYRESPONSESTREAMTYPE._serialized_start=423
  _VODSMARTSTRATEGYRESPONSESTREAMTYPE._serialized_end=682
  _VODSMARTSTRATEGYDATASTORESTATUS._serialized_start=685
  _VODSMARTSTRATEGYDATASTORESTATUS._serialized_end=915
  _VODGETSMARTSTRATEGYLITEPLAYINFORESULT._serialized_start=105
  _VODGETSMARTSTRATEGYLITEPLAYINFORESULT._serialized_end=420
# @@protoc_insertion_point(module_scope)
