# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_media.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cvod/business/vod_media.proto\x12\x1eVolcengine.Vod.Models.Business\x1a\x1dvod/business/vod_common.proto\"\xee\x01\n\x11VodMediaBasicInfo\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\r\n\x05Title\x18\x03 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x04 \x01(\t\x12\x11\n\tPosterUri\x18\x05 \x01(\t\x12\x15\n\rPublishStatus\x18\x06 \x01(\t\x12\x0c\n\x04Tags\x18\x07 \x03(\t\x12\x12\n\nCreateTime\x18\x08 \x01(\t\x12I\n\x0e\x43lassification\x18\t \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodClassification\"\xe1\x01\n\x0cVodMediaInfo\x12\x44\n\tBasicInfo\x18\x01 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodMediaBasicInfo\x12\x41\n\nSourceInfo\x18\x02 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodSourceInfo\x12H\n\x0eTranscodeInfos\x18\x03 \x03(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodTranscodeInfo\"q\n\x14VodGetMediaInfosData\x12\x43\n\rMediaInfoList\x18\x01 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodMediaInfo\x12\x14\n\x0cNotExistVids\x18\x02 \x03(\t\"2\n\x10VodStoreUriGroup\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x11\n\tStoreUris\x18\x02 \x03(\t\"u\n\x13VodGetRecPosterData\x12H\n\x0eStoreUriGroups\x18\x01 \x03(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodStoreUriGroup\x12\x14\n\x0cNotExistVids\x18\x02 \x03(\t\"*\n\x12VodDeleteMediaData\x12\x14\n\x0cNotExistVids\x18\x01 \x03(\t\"2\n\x17VodDeleteTranscodesData\x12\x17\n\x0fNotExistFileIds\x18\x01 \x03(\t\"\xa3\x01\n\x13VodGetMediaListData\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x43\n\rMediaInfoList\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodMediaInfo\x12\x12\n\nTotalCount\x18\x03 \x01(\x05\x12\x0e\n\x06Offset\x18\x04 \x01(\x05\x12\x10\n\x08PageSize\x18\x05 \x01(\x05\"6\n\x1bVodUpdateSubtitleStatusData\x12\x17\n\x0fNotExistFileIds\x18\x01 \x03(\t\"p\n\x13VodFileSubtitleInfo\x12\x0e\n\x06\x46ileId\x18\x01 \x01(\t\x12I\n\x10SubtitleInfoList\x18\x02 \x03(\x0b\x32/.Volcengine.Vod.Models.Business.VodSubtitleInfo\"\xcb\x01\n\x1aVodGetSubtitleInfoListData\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12Q\n\x14\x46ileSubtitleInfoList\x18\x02 \x03(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodFileSubtitleInfo\x12\x17\n\x0fNotExistFileIds\x18\x03 \x03(\t\x12\x12\n\nTotalCount\x18\x04 \x01(\x05\x12\x0e\n\x06Offset\x18\x05 \x01(\x05\x12\x10\n\x08PageSize\x18\x06 \x01(\x05\"q\n\x14VodFrameDataForAudit\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x13\n\x0b\x46rameNumber\x18\x02 \x01(\x05\x12\x13\n\x0b\x43utTimeMill\x18\x03 \x01(\x01\x12\r\n\x05Width\x18\x04 \x01(\x05\x12\x0e\n\x06Height\x18\x05 \x01(\x05\"b\n\x1aVodGetFramesForAuditResult\x12\x44\n\x06\x46rames\x18\x01 \x03(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodFrameDataForAudit\"\x9f\x01\n\x1aVodBetterFrameDataForAudit\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x13\n\x0b\x46rameNumber\x18\x02 \x01(\x05\x12\x13\n\x0b\x43utTimeMill\x18\x03 \x01(\x01\x12\r\n\x05Width\x18\x04 \x01(\x05\x12\x0e\n\x06Height\x18\x05 \x01(\x05\x12\x11\n\tCoverRate\x18\x06 \x01(\x01\x12\x13\n\x0bLBPHashCode\x18\x07 \x03(\x01\"n\n VodGetBetterFramesForAuditResult\x12J\n\x06\x46rames\x18\x01 \x03(\x0b\x32:.Volcengine.Vod.Models.Business.VodBetterFrameDataForAudit\"J\n\x14VodAudioInfoForAudit\x12\x10\n\x08StoreUri\x18\x01 \x01(\t\x12\x10\n\x08\x44uration\x18\x02 \x01(\x01\x12\x0e\n\x06\x46ormat\x18\x03 \x01(\t\"h\n\x1dVodGetAudioInfoForAuditResult\x12G\n\tAudioInfo\x18\x01 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodAudioInfoForAudit\"n\n\x1bVodASRUtteranceWordForAudit\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x15\n\rStartTimeMill\x18\x02 \x01(\x01\x12\x13\n\x0b\x45ndTimeMill\x18\x03 \x01(\x01\x12\x15\n\rBlankDuration\x18\x04 \x01(\x01\"<\n VodCreateVideoClassificationData\x12\x18\n\x10\x43lassificationId\x18\x01 \x01(\x03\"\xbb\x02\n\x11VodClassification\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x18\n\x10\x43lassificationId\x18\x02 \x01(\x03\x12\r\n\x05Level\x18\x03 \x01(\x05\x12\x16\n\x0e\x43lassification\x18\x04 \x01(\t\x12\x1e\n\x16ParentClassificationId\x18\x05 \x01(\x03\x12L\n\x11SubClassification\x18\x06 \x01(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodClassification\x12Q\n\x16SubClassificationTrees\x18\x07 \x03(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodClassification\x12\x11\n\tCreatedAt\x18\x08 \x01(\t\"m\n\x1bVodVideoClassificationsData\x12N\n\x13\x43lassificationTrees\x18\x01 \x03(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodClassification\"\xc5\x01\n\x17VodASRUtteranceForAudit\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x15\n\rStartTimeMill\x18\x02 \x01(\x01\x12\x13\n\x0b\x45ndTimeMill\x18\x03 \x01(\x01\x12J\n\x05Words\x18\x04 \x03(\x0b\x32;.Volcengine.Vod.Models.Business.VodASRUtteranceWordForAudit\x12\x10\n\x08Language\x18\x05 \x01(\t\x12\x12\n\nSpeechRate\x18\x06 \x01(\x01\">\n\x1cVodASRLanguageDetailForAudit\x12\x0c\n\x04Prob\x18\x01 \x01(\x01\x12\x10\n\x08Language\x18\x02 \x01(\t\"\xfc\x01\n\x12VodASRInfoForAudit\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12K\n\nUtterances\x18\x03 \x03(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodASRUtteranceForAudit\x12\x10\n\x08Language\x18\x04 \x01(\t\x12U\n\x0fLanguageDetails\x18\x05 \x03(\x0b\x32<.Volcengine.Vod.Models.Business.VodASRLanguageDetailForAudit\x12\x12\n\nSpeechRate\x18\x06 \x01(\x01\x12\x0e\n\x06Volume\x18\x07 \x01(\x01\"r\n.VodGetAutomaticSpeechRecognitionForAuditResult\x12@\n\x04Info\x18\x01 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodASRInfoForAudit\"S\n\x17VodAEDTimeRangeForAudit\x12\x15\n\rStartTimeMill\x18\x01 \x01(\x01\x12\x13\n\x0b\x45ndTimeMill\x18\x02 \x01(\x01\x12\x0c\n\x04Prob\x18\x03 \x01(\x01\"\x86\x01\n\x17VodAEDEventItemForAudit\x12\r\n\x05\x45vent\x18\x01 \x01(\t\x12\x0f\n\x07UttProb\x18\x02 \x01(\x01\x12K\n\nTimeRanges\x18\x03 \x03(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodAEDTimeRangeForAudit\"a\n\x12VodAEDInfoForAudit\x12K\n\nEventItems\x18\x01 \x03(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodAEDEventItemForAudit\"k\n\'VodGetAudioEventDetectionForAuditResult\x12@\n\x04Info\x18\x01 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodAEDInfoForAudit\"[\n\x0bVodSnapshot\x12\x0e\n\x06\x46ormat\x18\x01 \x01(\t\x12\x0e\n\x06Height\x18\x02 \x01(\x05\x12\r\n\x05Width\x18\x03 \x01(\x05\x12\x10\n\x08StoreUri\x18\x04 \x01(\t\x12\x0b\n\x03Url\x18\x05 \x01(\t\"\xb3\x01\n\x11VodSpriteSnapshot\x12\x0e\n\x06\x46ormat\x18\x01 \x01(\t\x12\x0f\n\x07ImgXLen\x18\x02 \x01(\x05\x12\x0f\n\x07ImgYLen\x18\x03 \x01(\x05\x12\x11\n\tCellWidth\x18\x04 \x01(\x05\x12\x12\n\nCellHeight\x18\x05 \x01(\x05\x12\x10\n\x08Interval\x18\x06 \x01(\x02\x12\x12\n\nCaptureNum\x18\x07 \x01(\x05\x12\x11\n\tStoreUris\x18\x08 \x03(\t\x12\x0c\n\x04Urls\x18\t \x03(\t\"\xa1\x03\n\x0fVodSnapshotData\x12\x11\n\tSpaceName\x18\x01 \x01(\t\x12\x0b\n\x03Vid\x18\x02 \x01(\t\x12\x44\n\x0fPosterSnapshots\x18\x03 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodSnapshot\x12\x45\n\x10\x44ynpostSnapshots\x18\x04 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodSnapshot\x12L\n\x17\x41nimatedPosterSnapshots\x18\x05 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodSnapshot\x12G\n\x12\x41iDynpostSnapshots\x18\x06 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodSnapshot\x12J\n\x0fSpriteSnapshots\x18\x07 \x03(\x0b\x32\x31.Volcengine.Vod.Models.Business.VodSpriteSnapshot*\xd0\x02\n VodFrameExtractingOptionForAudit\x12-\n)UndefinedVodFrameExtractingOptionForAudit\x10\x00\x12\'\n#FpsVodFrameExtractingOptionForAudit\x10\x01\x12\x32\n.NumberOfFramesVodFrameExtractingOptionForAudit\x10\x02\x12,\n(CutTimesVodFrameExtractingOptionForAudit\x10\x03\x12:\n6FpsLimitNumberOfFramesVodFrameExtractingOptionForAudit\x10\x04\x12\x36\n2OnlyFirstLastFrameVodFrameExtractingOptionForAudit\x10\x05\x42\xcc\x01\n)com.volcengine.service.vod.model.businessB\x08VodMediaP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_VODFRAMEEXTRACTINGOPTIONFORAUDIT = DESCRIPTOR.enum_types_by_name['VodFrameExtractingOptionForAudit']
VodFrameExtractingOptionForAudit = enum_type_wrapper.EnumTypeWrapper(_VODFRAMEEXTRACTINGOPTIONFORAUDIT)
UndefinedVodFrameExtractingOptionForAudit = 0
FpsVodFrameExtractingOptionForAudit = 1
NumberOfFramesVodFrameExtractingOptionForAudit = 2
CutTimesVodFrameExtractingOptionForAudit = 3
FpsLimitNumberOfFramesVodFrameExtractingOptionForAudit = 4
OnlyFirstLastFrameVodFrameExtractingOptionForAudit = 5


_VODMEDIABASICINFO = DESCRIPTOR.message_types_by_name['VodMediaBasicInfo']
_VODMEDIAINFO = DESCRIPTOR.message_types_by_name['VodMediaInfo']
_VODGETMEDIAINFOSDATA = DESCRIPTOR.message_types_by_name['VodGetMediaInfosData']
_VODSTOREURIGROUP = DESCRIPTOR.message_types_by_name['VodStoreUriGroup']
_VODGETRECPOSTERDATA = DESCRIPTOR.message_types_by_name['VodGetRecPosterData']
_VODDELETEMEDIADATA = DESCRIPTOR.message_types_by_name['VodDeleteMediaData']
_VODDELETETRANSCODESDATA = DESCRIPTOR.message_types_by_name['VodDeleteTranscodesData']
_VODGETMEDIALISTDATA = DESCRIPTOR.message_types_by_name['VodGetMediaListData']
_VODUPDATESUBTITLESTATUSDATA = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleStatusData']
_VODFILESUBTITLEINFO = DESCRIPTOR.message_types_by_name['VodFileSubtitleInfo']
_VODGETSUBTITLEINFOLISTDATA = DESCRIPTOR.message_types_by_name['VodGetSubtitleInfoListData']
_VODFRAMEDATAFORAUDIT = DESCRIPTOR.message_types_by_name['VodFrameDataForAudit']
_VODGETFRAMESFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetFramesForAuditResult']
_VODBETTERFRAMEDATAFORAUDIT = DESCRIPTOR.message_types_by_name['VodBetterFrameDataForAudit']
_VODGETBETTERFRAMESFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetBetterFramesForAuditResult']
_VODAUDIOINFOFORAUDIT = DESCRIPTOR.message_types_by_name['VodAudioInfoForAudit']
_VODGETAUDIOINFOFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetAudioInfoForAuditResult']
_VODASRUTTERANCEWORDFORAUDIT = DESCRIPTOR.message_types_by_name['VodASRUtteranceWordForAudit']
_VODCREATEVIDEOCLASSIFICATIONDATA = DESCRIPTOR.message_types_by_name['VodCreateVideoClassificationData']
_VODCLASSIFICATION = DESCRIPTOR.message_types_by_name['VodClassification']
_VODVIDEOCLASSIFICATIONSDATA = DESCRIPTOR.message_types_by_name['VodVideoClassificationsData']
_VODASRUTTERANCEFORAUDIT = DESCRIPTOR.message_types_by_name['VodASRUtteranceForAudit']
_VODASRLANGUAGEDETAILFORAUDIT = DESCRIPTOR.message_types_by_name['VodASRLanguageDetailForAudit']
_VODASRINFOFORAUDIT = DESCRIPTOR.message_types_by_name['VodASRInfoForAudit']
_VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetAutomaticSpeechRecognitionForAuditResult']
_VODAEDTIMERANGEFORAUDIT = DESCRIPTOR.message_types_by_name['VodAEDTimeRangeForAudit']
_VODAEDEVENTITEMFORAUDIT = DESCRIPTOR.message_types_by_name['VodAEDEventItemForAudit']
_VODAEDINFOFORAUDIT = DESCRIPTOR.message_types_by_name['VodAEDInfoForAudit']
_VODGETAUDIOEVENTDETECTIONFORAUDITRESULT = DESCRIPTOR.message_types_by_name['VodGetAudioEventDetectionForAuditResult']
_VODSNAPSHOT = DESCRIPTOR.message_types_by_name['VodSnapshot']
_VODSPRITESNAPSHOT = DESCRIPTOR.message_types_by_name['VodSpriteSnapshot']
_VODSNAPSHOTDATA = DESCRIPTOR.message_types_by_name['VodSnapshotData']
VodMediaBasicInfo = _reflection.GeneratedProtocolMessageType('VodMediaBasicInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODMEDIABASICINFO,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodMediaBasicInfo)
  })
_sym_db.RegisterMessage(VodMediaBasicInfo)

VodMediaInfo = _reflection.GeneratedProtocolMessageType('VodMediaInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODMEDIAINFO,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodMediaInfo)
  })
_sym_db.RegisterMessage(VodMediaInfo)

VodGetMediaInfosData = _reflection.GeneratedProtocolMessageType('VodGetMediaInfosData', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIAINFOSDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetMediaInfosData)
  })
_sym_db.RegisterMessage(VodGetMediaInfosData)

VodStoreUriGroup = _reflection.GeneratedProtocolMessageType('VodStoreUriGroup', (_message.Message,), {
  'DESCRIPTOR' : _VODSTOREURIGROUP,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodStoreUriGroup)
  })
_sym_db.RegisterMessage(VodStoreUriGroup)

VodGetRecPosterData = _reflection.GeneratedProtocolMessageType('VodGetRecPosterData', (_message.Message,), {
  'DESCRIPTOR' : _VODGETRECPOSTERDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetRecPosterData)
  })
_sym_db.RegisterMessage(VodGetRecPosterData)

VodDeleteMediaData = _reflection.GeneratedProtocolMessageType('VodDeleteMediaData', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEMEDIADATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodDeleteMediaData)
  })
_sym_db.RegisterMessage(VodDeleteMediaData)

VodDeleteTranscodesData = _reflection.GeneratedProtocolMessageType('VodDeleteTranscodesData', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETETRANSCODESDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodDeleteTranscodesData)
  })
_sym_db.RegisterMessage(VodDeleteTranscodesData)

VodGetMediaListData = _reflection.GeneratedProtocolMessageType('VodGetMediaListData', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIALISTDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetMediaListData)
  })
_sym_db.RegisterMessage(VodGetMediaListData)

VodUpdateSubtitleStatusData = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleStatusData', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLESTATUSDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodUpdateSubtitleStatusData)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleStatusData)

VodFileSubtitleInfo = _reflection.GeneratedProtocolMessageType('VodFileSubtitleInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODFILESUBTITLEINFO,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodFileSubtitleInfo)
  })
_sym_db.RegisterMessage(VodFileSubtitleInfo)

VodGetSubtitleInfoListData = _reflection.GeneratedProtocolMessageType('VodGetSubtitleInfoListData', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSUBTITLEINFOLISTDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetSubtitleInfoListData)
  })
_sym_db.RegisterMessage(VodGetSubtitleInfoListData)

VodFrameDataForAudit = _reflection.GeneratedProtocolMessageType('VodFrameDataForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODFRAMEDATAFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodFrameDataForAudit)
  })
_sym_db.RegisterMessage(VodFrameDataForAudit)

VodGetFramesForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetFramesForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETFRAMESFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetFramesForAuditResult)
  })
_sym_db.RegisterMessage(VodGetFramesForAuditResult)

VodBetterFrameDataForAudit = _reflection.GeneratedProtocolMessageType('VodBetterFrameDataForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODBETTERFRAMEDATAFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodBetterFrameDataForAudit)
  })
_sym_db.RegisterMessage(VodBetterFrameDataForAudit)

VodGetBetterFramesForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetBetterFramesForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETBETTERFRAMESFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetBetterFramesForAuditResult)
  })
_sym_db.RegisterMessage(VodGetBetterFramesForAuditResult)

VodAudioInfoForAudit = _reflection.GeneratedProtocolMessageType('VodAudioInfoForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODAUDIOINFOFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAudioInfoForAudit)
  })
_sym_db.RegisterMessage(VodAudioInfoForAudit)

VodGetAudioInfoForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetAudioInfoForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOINFOFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetAudioInfoForAuditResult)
  })
_sym_db.RegisterMessage(VodGetAudioInfoForAuditResult)

VodASRUtteranceWordForAudit = _reflection.GeneratedProtocolMessageType('VodASRUtteranceWordForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODASRUTTERANCEWORDFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodASRUtteranceWordForAudit)
  })
_sym_db.RegisterMessage(VodASRUtteranceWordForAudit)

VodCreateVideoClassificationData = _reflection.GeneratedProtocolMessageType('VodCreateVideoClassificationData', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEVIDEOCLASSIFICATIONDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCreateVideoClassificationData)
  })
_sym_db.RegisterMessage(VodCreateVideoClassificationData)

VodClassification = _reflection.GeneratedProtocolMessageType('VodClassification', (_message.Message,), {
  'DESCRIPTOR' : _VODCLASSIFICATION,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodClassification)
  })
_sym_db.RegisterMessage(VodClassification)

VodVideoClassificationsData = _reflection.GeneratedProtocolMessageType('VodVideoClassificationsData', (_message.Message,), {
  'DESCRIPTOR' : _VODVIDEOCLASSIFICATIONSDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodVideoClassificationsData)
  })
_sym_db.RegisterMessage(VodVideoClassificationsData)

VodASRUtteranceForAudit = _reflection.GeneratedProtocolMessageType('VodASRUtteranceForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODASRUTTERANCEFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodASRUtteranceForAudit)
  })
_sym_db.RegisterMessage(VodASRUtteranceForAudit)

VodASRLanguageDetailForAudit = _reflection.GeneratedProtocolMessageType('VodASRLanguageDetailForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODASRLANGUAGEDETAILFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodASRLanguageDetailForAudit)
  })
_sym_db.RegisterMessage(VodASRLanguageDetailForAudit)

VodASRInfoForAudit = _reflection.GeneratedProtocolMessageType('VodASRInfoForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODASRINFOFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodASRInfoForAudit)
  })
_sym_db.RegisterMessage(VodASRInfoForAudit)

VodGetAutomaticSpeechRecognitionForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetAutomaticSpeechRecognitionForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetAutomaticSpeechRecognitionForAuditResult)
  })
_sym_db.RegisterMessage(VodGetAutomaticSpeechRecognitionForAuditResult)

VodAEDTimeRangeForAudit = _reflection.GeneratedProtocolMessageType('VodAEDTimeRangeForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODAEDTIMERANGEFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAEDTimeRangeForAudit)
  })
_sym_db.RegisterMessage(VodAEDTimeRangeForAudit)

VodAEDEventItemForAudit = _reflection.GeneratedProtocolMessageType('VodAEDEventItemForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODAEDEVENTITEMFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAEDEventItemForAudit)
  })
_sym_db.RegisterMessage(VodAEDEventItemForAudit)

VodAEDInfoForAudit = _reflection.GeneratedProtocolMessageType('VodAEDInfoForAudit', (_message.Message,), {
  'DESCRIPTOR' : _VODAEDINFOFORAUDIT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAEDInfoForAudit)
  })
_sym_db.RegisterMessage(VodAEDInfoForAudit)

VodGetAudioEventDetectionForAuditResult = _reflection.GeneratedProtocolMessageType('VodGetAudioEventDetectionForAuditResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOEVENTDETECTIONFORAUDITRESULT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetAudioEventDetectionForAuditResult)
  })
_sym_db.RegisterMessage(VodGetAudioEventDetectionForAuditResult)

VodSnapshot = _reflection.GeneratedProtocolMessageType('VodSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _VODSNAPSHOT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSnapshot)
  })
_sym_db.RegisterMessage(VodSnapshot)

VodSpriteSnapshot = _reflection.GeneratedProtocolMessageType('VodSpriteSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _VODSPRITESNAPSHOT,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSpriteSnapshot)
  })
_sym_db.RegisterMessage(VodSpriteSnapshot)

VodSnapshotData = _reflection.GeneratedProtocolMessageType('VodSnapshotData', (_message.Message,), {
  'DESCRIPTOR' : _VODSNAPSHOTDATA,
  '__module__' : 'vod.business.vod_media_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSnapshotData)
  })
_sym_db.RegisterMessage(VodSnapshotData)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\010VodMediaP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODFRAMEEXTRACTINGOPTIONFORAUDIT._serialized_start=4523
  _VODFRAMEEXTRACTINGOPTIONFORAUDIT._serialized_end=4859
  _VODMEDIABASICINFO._serialized_start=96
  _VODMEDIABASICINFO._serialized_end=334
  _VODMEDIAINFO._serialized_start=337
  _VODMEDIAINFO._serialized_end=562
  _VODGETMEDIAINFOSDATA._serialized_start=564
  _VODGETMEDIAINFOSDATA._serialized_end=677
  _VODSTOREURIGROUP._serialized_start=679
  _VODSTOREURIGROUP._serialized_end=729
  _VODGETRECPOSTERDATA._serialized_start=731
  _VODGETRECPOSTERDATA._serialized_end=848
  _VODDELETEMEDIADATA._serialized_start=850
  _VODDELETEMEDIADATA._serialized_end=892
  _VODDELETETRANSCODESDATA._serialized_start=894
  _VODDELETETRANSCODESDATA._serialized_end=944
  _VODGETMEDIALISTDATA._serialized_start=947
  _VODGETMEDIALISTDATA._serialized_end=1110
  _VODUPDATESUBTITLESTATUSDATA._serialized_start=1112
  _VODUPDATESUBTITLESTATUSDATA._serialized_end=1166
  _VODFILESUBTITLEINFO._serialized_start=1168
  _VODFILESUBTITLEINFO._serialized_end=1280
  _VODGETSUBTITLEINFOLISTDATA._serialized_start=1283
  _VODGETSUBTITLEINFOLISTDATA._serialized_end=1486
  _VODFRAMEDATAFORAUDIT._serialized_start=1488
  _VODFRAMEDATAFORAUDIT._serialized_end=1601
  _VODGETFRAMESFORAUDITRESULT._serialized_start=1603
  _VODGETFRAMESFORAUDITRESULT._serialized_end=1701
  _VODBETTERFRAMEDATAFORAUDIT._serialized_start=1704
  _VODBETTERFRAMEDATAFORAUDIT._serialized_end=1863
  _VODGETBETTERFRAMESFORAUDITRESULT._serialized_start=1865
  _VODGETBETTERFRAMESFORAUDITRESULT._serialized_end=1975
  _VODAUDIOINFOFORAUDIT._serialized_start=1977
  _VODAUDIOINFOFORAUDIT._serialized_end=2051
  _VODGETAUDIOINFOFORAUDITRESULT._serialized_start=2053
  _VODGETAUDIOINFOFORAUDITRESULT._serialized_end=2157
  _VODASRUTTERANCEWORDFORAUDIT._serialized_start=2159
  _VODASRUTTERANCEWORDFORAUDIT._serialized_end=2269
  _VODCREATEVIDEOCLASSIFICATIONDATA._serialized_start=2271
  _VODCREATEVIDEOCLASSIFICATIONDATA._serialized_end=2331
  _VODCLASSIFICATION._serialized_start=2334
  _VODCLASSIFICATION._serialized_end=2649
  _VODVIDEOCLASSIFICATIONSDATA._serialized_start=2651
  _VODVIDEOCLASSIFICATIONSDATA._serialized_end=2760
  _VODASRUTTERANCEFORAUDIT._serialized_start=2763
  _VODASRUTTERANCEFORAUDIT._serialized_end=2960
  _VODASRLANGUAGEDETAILFORAUDIT._serialized_start=2962
  _VODASRLANGUAGEDETAILFORAUDIT._serialized_end=3024
  _VODASRINFOFORAUDIT._serialized_start=3027
  _VODASRINFOFORAUDIT._serialized_end=3279
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESULT._serialized_start=3281
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESULT._serialized_end=3395
  _VODAEDTIMERANGEFORAUDIT._serialized_start=3397
  _VODAEDTIMERANGEFORAUDIT._serialized_end=3480
  _VODAEDEVENTITEMFORAUDIT._serialized_start=3483
  _VODAEDEVENTITEMFORAUDIT._serialized_end=3617
  _VODAEDINFOFORAUDIT._serialized_start=3619
  _VODAEDINFOFORAUDIT._serialized_end=3716
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESULT._serialized_start=3718
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESULT._serialized_end=3825
  _VODSNAPSHOT._serialized_start=3827
  _VODSNAPSHOT._serialized_end=3918
  _VODSPRITESNAPSHOT._serialized_start=3921
  _VODSPRITESNAPSHOT._serialized_end=4100
  _VODSNAPSHOTDATA._serialized_start=4103
  _VODSNAPSHOTDATA._serialized_end=4520
# @@protoc_insertion_point(module_scope)
