# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_workflow.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvod/business/vod_workflow.proto\x12\x1eVolcengine.Vod.Models.Business\"\'\n\x16VodStartWorkflowResult\x12\r\n\x05RunId\x18\x01 \x01(\t\"\xdc\x01\n\x0eWorkflowParams\x12\x46\n\x0eOverrideParams\x18\x01 \x01(\x0b\x32..Volcengine.Vod.Models.Business.OverrideParams\x12P\n\tCondition\x18\x02 \x03(\x0b\x32=.Volcengine.Vod.Models.Business.WorkflowParams.ConditionEntry\x1a\x30\n\x0e\x43onditionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\xb0\x02\n\x0eOverrideParams\x12:\n\x04Logo\x18\x01 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.LogoOverride\x12N\n\x0eTranscodeVideo\x18\x02 \x03(\x0b\x32\x36.Volcengine.Vod.Models.Business.TranscodeVideoOverride\x12N\n\x0eTranscodeAudio\x18\x03 \x03(\x0b\x32\x36.Volcengine.Vod.Models.Business.TranscodeAudioOverride\x12\x42\n\x08Snapshot\x18\x04 \x03(\x0b\x32\x30.Volcengine.Vod.Models.Business.SnapshotOverride\"\x95\x01\n\x0cLogoOverride\x12\x12\n\nTemplateId\x18\x01 \x01(\t\x12\x44\n\x04Vars\x18\x02 \x03(\x0b\x32\x36.Volcengine.Vod.Models.Business.LogoOverride.VarsEntry\x1a+\n\tVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x16TranscodeVideoOverride\x12\x12\n\nTemplateId\x18\x01 \x03(\t\x12\x32\n\x04\x43lip\x18\x02 \x01(\x0b\x32$.Volcengine.Vod.Models.Business.Clip\"*\n\x04\x43lip\x12\x11\n\tStartTime\x18\x01 \x01(\x05\x12\x0f\n\x07\x45ndTime\x18\x02 \x01(\x05\"`\n\x16TranscodeAudioOverride\x12\x12\n\nTemplateId\x18\x01 \x03(\t\x12\x32\n\x04\x43lip\x18\x02 \x01(\x0b\x32$.Volcengine.Vod.Models.Business.Clip\"R\n\x10SnapshotOverride\x12\x12\n\nTemplateId\x18\x01 \x03(\t\x12\x12\n\nOffsetTime\x18\x02 \x01(\x05\x12\x16\n\x0eOffsetTimeList\x18\x03 \x03(\x05\"\xa5\x01\n\x0fTranscodeResult\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12>\n\nInspection\x18\x02 \x01(\x0b\x32*.Volcengine.Vod.Models.Business.Inspection\x12\x45\n\x0c\x43\x61tegoryTags\x18\x03 \x03(\x0b\x32/.Volcengine.Vod.Models.Business.CategoryTagInfo\"\x82\x01\n\nInspection\x12\x38\n\x07Quality\x18\x01 \x01(\x0b\x32\'.Volcengine.Vod.Models.Business.Quality\x12:\n\x06\x44\x65Logo\x18\x02 \x03(\x0b\x32*.Volcengine.Vod.Models.Business.DeLogoInfo\"\x88\x01\n\x07Quality\x12=\n\x06Visual\x18\x01 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VisualQuality\x12>\n\nVolumeInfo\x18\x02 \x01(\x0b\x32*.Volcengine.Vod.Models.Business.VolumeInfo\"q\n\nDeLogoInfo\x12\x13\n\x0b\x41nchorWidth\x18\x01 \x01(\x03\x12\x14\n\x0c\x41nchorHeight\x18\x02 \x01(\x03\x12\x0c\n\x04PosX\x18\x03 \x01(\x03\x12\x0c\n\x04PosY\x18\x04 \x01(\x03\x12\r\n\x05SizeX\x18\x05 \x01(\x03\x12\r\n\x05SizeY\x18\x06 \x01(\x03\"|\n\rVisualQuality\x12\x0f\n\x07VQScore\x18\x01 \x01(\x01\x12\x10\n\x08\x43ontrast\x18\x02 \x01(\x01\x12\x14\n\x0c\x43olorfulness\x18\x03 \x01(\x01\x12\x12\n\nBrightness\x18\x04 \x01(\x01\x12\x0f\n\x07Texture\x18\x05 \x01(\x01\x12\r\n\x05Noise\x18\x06 \x01(\x01\"S\n\nVolumeInfo\x12\x10\n\x08Loudness\x18\x01 \x01(\x01\x12\x0c\n\x04Peak\x18\x02 \x01(\x01\x12\x12\n\nMeanVolume\x18\x03 \x01(\x01\x12\x11\n\tMaxVolume\x18\x04 \x01(\x01\"\xd6\x01\n\x0f\x43\x61tegoryTagInfo\x12\r\n\x05TagId\x18\x01 \x01(\x03\x12\x0c\n\x04Prob\x18\x02 \x01(\x01\x12\x0f\n\x07TagName\x18\x03 \x01(\t\x12\r\n\x05Level\x18\x04 \x01(\x03\x12S\n\nParentInfo\x18\x05 \x03(\x0b\x32?.Volcengine.Vod.Models.Business.CategoryTagInfo.ParentInfoEntry\x1a\x31\n\x0fParentInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\xcc\x01\n)com.volcengine.service.vod.model.businessB\x0bVodWorkflowP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODSTARTWORKFLOWRESULT = DESCRIPTOR.message_types_by_name['VodStartWorkflowResult']
_WORKFLOWPARAMS = DESCRIPTOR.message_types_by_name['WorkflowParams']
_WORKFLOWPARAMS_CONDITIONENTRY = _WORKFLOWPARAMS.nested_types_by_name['ConditionEntry']
_OVERRIDEPARAMS = DESCRIPTOR.message_types_by_name['OverrideParams']
_LOGOOVERRIDE = DESCRIPTOR.message_types_by_name['LogoOverride']
_LOGOOVERRIDE_VARSENTRY = _LOGOOVERRIDE.nested_types_by_name['VarsEntry']
_TRANSCODEVIDEOOVERRIDE = DESCRIPTOR.message_types_by_name['TranscodeVideoOverride']
_CLIP = DESCRIPTOR.message_types_by_name['Clip']
_TRANSCODEAUDIOOVERRIDE = DESCRIPTOR.message_types_by_name['TranscodeAudioOverride']
_SNAPSHOTOVERRIDE = DESCRIPTOR.message_types_by_name['SnapshotOverride']
_TRANSCODERESULT = DESCRIPTOR.message_types_by_name['TranscodeResult']
_INSPECTION = DESCRIPTOR.message_types_by_name['Inspection']
_QUALITY = DESCRIPTOR.message_types_by_name['Quality']
_DELOGOINFO = DESCRIPTOR.message_types_by_name['DeLogoInfo']
_VISUALQUALITY = DESCRIPTOR.message_types_by_name['VisualQuality']
_VOLUMEINFO = DESCRIPTOR.message_types_by_name['VolumeInfo']
_CATEGORYTAGINFO = DESCRIPTOR.message_types_by_name['CategoryTagInfo']
_CATEGORYTAGINFO_PARENTINFOENTRY = _CATEGORYTAGINFO.nested_types_by_name['ParentInfoEntry']
VodStartWorkflowResult = _reflection.GeneratedProtocolMessageType('VodStartWorkflowResult', (_message.Message,), {
  'DESCRIPTOR' : _VODSTARTWORKFLOWRESULT,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodStartWorkflowResult)
  })
_sym_db.RegisterMessage(VodStartWorkflowResult)

WorkflowParams = _reflection.GeneratedProtocolMessageType('WorkflowParams', (_message.Message,), {

  'ConditionEntry' : _reflection.GeneratedProtocolMessageType('ConditionEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKFLOWPARAMS_CONDITIONENTRY,
    '__module__' : 'vod.business.vod_workflow_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.WorkflowParams.ConditionEntry)
    })
  ,
  'DESCRIPTOR' : _WORKFLOWPARAMS,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.WorkflowParams)
  })
_sym_db.RegisterMessage(WorkflowParams)
_sym_db.RegisterMessage(WorkflowParams.ConditionEntry)

OverrideParams = _reflection.GeneratedProtocolMessageType('OverrideParams', (_message.Message,), {
  'DESCRIPTOR' : _OVERRIDEPARAMS,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.OverrideParams)
  })
_sym_db.RegisterMessage(OverrideParams)

LogoOverride = _reflection.GeneratedProtocolMessageType('LogoOverride', (_message.Message,), {

  'VarsEntry' : _reflection.GeneratedProtocolMessageType('VarsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGOOVERRIDE_VARSENTRY,
    '__module__' : 'vod.business.vod_workflow_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.LogoOverride.VarsEntry)
    })
  ,
  'DESCRIPTOR' : _LOGOOVERRIDE,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.LogoOverride)
  })
_sym_db.RegisterMessage(LogoOverride)
_sym_db.RegisterMessage(LogoOverride.VarsEntry)

TranscodeVideoOverride = _reflection.GeneratedProtocolMessageType('TranscodeVideoOverride', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCODEVIDEOOVERRIDE,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.TranscodeVideoOverride)
  })
_sym_db.RegisterMessage(TranscodeVideoOverride)

Clip = _reflection.GeneratedProtocolMessageType('Clip', (_message.Message,), {
  'DESCRIPTOR' : _CLIP,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.Clip)
  })
_sym_db.RegisterMessage(Clip)

TranscodeAudioOverride = _reflection.GeneratedProtocolMessageType('TranscodeAudioOverride', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCODEAUDIOOVERRIDE,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.TranscodeAudioOverride)
  })
_sym_db.RegisterMessage(TranscodeAudioOverride)

SnapshotOverride = _reflection.GeneratedProtocolMessageType('SnapshotOverride', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTOVERRIDE,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.SnapshotOverride)
  })
_sym_db.RegisterMessage(SnapshotOverride)

TranscodeResult = _reflection.GeneratedProtocolMessageType('TranscodeResult', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCODERESULT,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.TranscodeResult)
  })
_sym_db.RegisterMessage(TranscodeResult)

Inspection = _reflection.GeneratedProtocolMessageType('Inspection', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTION,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.Inspection)
  })
_sym_db.RegisterMessage(Inspection)

Quality = _reflection.GeneratedProtocolMessageType('Quality', (_message.Message,), {
  'DESCRIPTOR' : _QUALITY,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.Quality)
  })
_sym_db.RegisterMessage(Quality)

DeLogoInfo = _reflection.GeneratedProtocolMessageType('DeLogoInfo', (_message.Message,), {
  'DESCRIPTOR' : _DELOGOINFO,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DeLogoInfo)
  })
_sym_db.RegisterMessage(DeLogoInfo)

VisualQuality = _reflection.GeneratedProtocolMessageType('VisualQuality', (_message.Message,), {
  'DESCRIPTOR' : _VISUALQUALITY,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VisualQuality)
  })
_sym_db.RegisterMessage(VisualQuality)

VolumeInfo = _reflection.GeneratedProtocolMessageType('VolumeInfo', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMEINFO,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VolumeInfo)
  })
_sym_db.RegisterMessage(VolumeInfo)

CategoryTagInfo = _reflection.GeneratedProtocolMessageType('CategoryTagInfo', (_message.Message,), {

  'ParentInfoEntry' : _reflection.GeneratedProtocolMessageType('ParentInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _CATEGORYTAGINFO_PARENTINFOENTRY,
    '__module__' : 'vod.business.vod_workflow_pb2'
    # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.CategoryTagInfo.ParentInfoEntry)
    })
  ,
  'DESCRIPTOR' : _CATEGORYTAGINFO,
  '__module__' : 'vod.business.vod_workflow_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.CategoryTagInfo)
  })
_sym_db.RegisterMessage(CategoryTagInfo)
_sym_db.RegisterMessage(CategoryTagInfo.ParentInfoEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\013VodWorkflowP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _WORKFLOWPARAMS_CONDITIONENTRY._options = None
  _WORKFLOWPARAMS_CONDITIONENTRY._serialized_options = b'8\001'
  _LOGOOVERRIDE_VARSENTRY._options = None
  _LOGOOVERRIDE_VARSENTRY._serialized_options = b'8\001'
  _CATEGORYTAGINFO_PARENTINFOENTRY._options = None
  _CATEGORYTAGINFO_PARENTINFOENTRY._serialized_options = b'8\001'
  _VODSTARTWORKFLOWRESULT._serialized_start=67
  _VODSTARTWORKFLOWRESULT._serialized_end=106
  _WORKFLOWPARAMS._serialized_start=109
  _WORKFLOWPARAMS._serialized_end=329
  _WORKFLOWPARAMS_CONDITIONENTRY._serialized_start=281
  _WORKFLOWPARAMS_CONDITIONENTRY._serialized_end=329
  _OVERRIDEPARAMS._serialized_start=332
  _OVERRIDEPARAMS._serialized_end=636
  _LOGOOVERRIDE._serialized_start=639
  _LOGOOVERRIDE._serialized_end=788
  _LOGOOVERRIDE_VARSENTRY._serialized_start=745
  _LOGOOVERRIDE_VARSENTRY._serialized_end=788
  _TRANSCODEVIDEOOVERRIDE._serialized_start=790
  _TRANSCODEVIDEOOVERRIDE._serialized_end=886
  _CLIP._serialized_start=888
  _CLIP._serialized_end=930
  _TRANSCODEAUDIOOVERRIDE._serialized_start=932
  _TRANSCODEAUDIOOVERRIDE._serialized_end=1028
  _SNAPSHOTOVERRIDE._serialized_start=1030
  _SNAPSHOTOVERRIDE._serialized_end=1112
  _TRANSCODERESULT._serialized_start=1115
  _TRANSCODERESULT._serialized_end=1280
  _INSPECTION._serialized_start=1283
  _INSPECTION._serialized_end=1413
  _QUALITY._serialized_start=1416
  _QUALITY._serialized_end=1552
  _DELOGOINFO._serialized_start=1554
  _DELOGOINFO._serialized_end=1667
  _VISUALQUALITY._serialized_start=1669
  _VISUALQUALITY._serialized_end=1793
  _VOLUMEINFO._serialized_start=1795
  _VOLUMEINFO._serialized_end=1878
  _CATEGORYTAGINFO._serialized_start=1881
  _CATEGORYTAGINFO._serialized_end=2095
  _CATEGORYTAGINFO_PARENTINFOENTRY._serialized_start=2046
  _CATEGORYTAGINFO_PARENTINFOENTRY._serialized_end=2095
# @@protoc_insertion_point(module_scope)
