# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/response/response_vod.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.base.models.base import base_pb2 as base_dot_base__pb2
from volcengine.vod.models.business import vod_play_pb2 as vod_dot_business_dot_vod__play__pb2
from volcengine.vod.models.business import vod_media_pb2 as vod_dot_business_dot_vod__media__pb2
from volcengine.vod.models.business import vod_upload_pb2 as vod_dot_business_dot_vod__upload__pb2
from volcengine.vod.models.business import vod_workflow_pb2 as vod_dot_business_dot_vod__workflow__pb2
from volcengine.vod.models.business import vod_space_pb2 as vod_dot_business_dot_vod__space__pb2
from volcengine.vod.models.business import vod_cdn_pb2 as vod_dot_business_dot_vod__cdn__pb2
from volcengine.vod.models.business import vod_common_pb2 as vod_dot_business_dot_vod__common__pb2
from volcengine.vod.models.business import vod_smart_strategy_pb2 as vod_dot_business_dot_vod__smart__strategy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fvod/response/response_vod.proto\x12\x1eVolcengine.Vod.Models.Response\x1a\x0f\x62\x61se/base.proto\x1a\x1bvod/business/vod_play.proto\x1a\x1cvod/business/vod_media.proto\x1a\x1dvod/business/vod_upload.proto\x1a\x1fvod/business/vod_workflow.proto\x1a\x1cvod/business/vod_space.proto\x1a\x1avod/business/vod_cdn.proto\x1a\x1dvod/business/vod_common.proto\x1a%vod/business/vod_smart_strategy.proto\"\xaa\x01\n\x19VodGetAllPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodAllPlayInfoResult\"\xa3\x01\n\x16VodGetPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodPlayInfoModel\"\xb7\x01\n\x1eVodGetOriginalPlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodGetOriginalPlayInfoResult\"\xbb\x01\n VodGetPrivateDrmPlayAuthResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12N\n\x06Result\x18\x02 \x01(\x0b\x32>.Volcengine.Vod.Models.Business.VodGetPrivateDrmPlayAuthResult\"\xb7\x01\n\x1eVodGetHlsDecryptionKeyResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodGetHlsDecryptionKeyResult\"\xd3\x01\n,VodGetPlayInfoWithLiveTimeShiftSceneResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12Z\n\x06Result\x18\x02 \x01(\x0b\x32J.Volcengine.Vod.Models.Business.VodGetPlayInfoWithLiveTimeShiftSceneResult\"\xa0\x01\n\x16VodUploadMediaResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12=\n\x06Result\x18\x02 \x01(\x0b\x32-.Volcengine.Vod.Models.Business.VodCommitData\"\xa7\x01\n\x1eVodQueryUploadTaskInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Vod.Models.Business.VodQueryData\"\xa3\x01\n\x14VodUrlUploadResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodUrlResponseData\"\xaf\x01\n\x1aVodApplyUploadInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12H\n\x06Result\x18\x02 \x01(\x0b\x32\x38.Volcengine.Vod.Models.Business.VodApplyUploadInfoResult\"\xb1\x01\n\x1bVodCommitUploadInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodCommitUploadInfoResult\"\xa9\x01\n\x18VodGetMediaInfosResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x44\n\x06Result\x18\x02 \x01(\x0b\x32\x34.Volcengine.Vod.Models.Business.VodGetMediaInfosData\"e\n\x1aVodUpdateMediaInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xaf\x01\n\x1fVodGetRecommendedPosterResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetRecPosterData\"n\n#VodUpdateMediaPublishStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xa5\x01\n\x16VodDeleteMediaResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x42\n\x06Result\x18\x02 \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodDeleteMediaData\"\xaf\x01\n\x1bVodDeleteTranscodesResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12G\n\x06Result\x18\x02 \x01(\x0b\x32\x37.Volcengine.Vod.Models.Business.VodDeleteTranscodesData\"\xa7\x01\n\x17VodGetMediaListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodGetMediaListData\"\xb5\x01\n\x1eVodGetSubtitleInfoListResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetSubtitleInfoListData\"\xb7\x01\n\x1fVodUpdateSubtitleStatusResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Vod.Models.Business.VodUpdateSubtitleStatusData\"h\n\x1dVodUpdateSubtitleInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xb8\x01\n!VodGetAuditFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetFramesForAuditResult\"\xb5\x01\n\x1eVodGetMLFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12J\n\x06Result\x18\x02 \x01(\x0b\x32:.Volcengine.Vod.Models.Business.VodGetFramesForAuditResult\"\xbf\x01\n\"VodGetBetterFramesForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12P\n\x06Result\x18\x02 \x01(\x0b\x32@.Volcengine.Vod.Models.Business.VodGetBetterFramesForAuditResult\"\xb9\x01\n\x1fVodGetAudioInfoForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12M\n\x06Result\x18\x02 \x01(\x0b\x32=.Volcengine.Vod.Models.Business.VodGetAudioInfoForAuditResult\"\xdb\x01\n0VodGetAutomaticSpeechRecognitionForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12^\n\x06Result\x18\x02 \x01(\x0b\x32N.Volcengine.Vod.Models.Business.VodGetAutomaticSpeechRecognitionForAuditResult\"\xcd\x01\n)VodGetAudioEventDetectionForAuditResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12W\n\x06Result\x18\x02 \x01(\x0b\x32G.Volcengine.Vod.Models.Business.VodGetAudioEventDetectionForAuditResult\"\xc1\x01\n$VodCreateVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12P\n\x06Result\x18\x02 \x01(\x0b\x32@.Volcengine.Vod.Models.Business.VodCreateVideoClassificationData\"o\n$VodUpdateVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"o\n$VodDeleteVideoClassificationResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xbb\x01\n#VodListVideoClassificationsResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12K\n\x06Result\x18\x02 \x01(\x0b\x32;.Volcengine.Vod.Models.Business.VodVideoClassificationsData\"\xa4\x01\n\x18VodListSnapshotsResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.VodSnapshotData\"\xab\x01\n\x18VodStartWorkflowResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodStartWorkflowResult\"\xae\x01\n\"VodRetrieveTranscodeResultResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12?\n\x06Result\x18\x02 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.TranscodeResult\"a\n\x16VodCreateSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\x9d\x01\n\x14VodListSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodSpaceInfo\"\xa2\x01\n\x19VodGetSpaceDetailResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x01(\x0b\x32,.Volcengine.Vod.Models.Business.VodSpaceInfo\"a\n\x16VodUpdateSpaceResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"m\n\"VodUpdateSpaceUploadConfigResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xa5\x01\n\x15VodListDomainResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x43\n\x06Result\x18\x02 \x01(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodDomainConfigInfo\"\xb2\x01\n\x1fVodCreateCdnRefreshTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodCreateCdnTaskResult\"\xb2\x01\n\x1fVodCreateCdnPreloadTaskResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12\x46\n\x06Result\x18\x02 \x01(\x0b\x32\x36.Volcengine.Vod.Models.Business.VodCreateCdnTaskResult\"\xa4\x01\n\x17VodListCdnTasksResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12@\n\x06Result\x18\x02 \x01(\x0b\x32\x30.Volcengine.Vod.Models.Business.VodCdnTaskResult\"\xb1\x01\n\x1bVodListCdnAccessLogResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12I\n\x06Result\x18\x02 \x01(\x0b\x32\x39.Volcengine.Vod.Models.Business.VodListCdnAccessLogResult\"\xb7\x01\n\x1eVodListCdnTopAccessUrlResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodListCdnTopAccessUrlResult\"\xcd\x01\n)VodDescribeVodDomainBandwidthDataResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12W\n\x06Result\x18\x02 \x01(\x0b\x32G.Volcengine.Vod.Models.Business.VodDescribeVodDomainBandwidthDataResult\"\xb7\x01\n\x1eVodCdnStatisticsCommonResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12L\n\x06Result\x18\x02 \x01(\x0b\x32<.Volcengine.Vod.Models.Business.VodCdnStatisticsCommonResult\"\xa2\x01\n\x19VodDescribeIPInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12<\n\x06Result\x18\x02 \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodCdnIpInfo\"m\n\"VodAddCallbackSubscriptionResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"f\n\x1bVodSetCallbackEventResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\"\xc9\x01\n\'VodGetSmartStrategyLitePlayInfoResponse\x12G\n\x10ResponseMetadata\x18\x01 \x01(\x0b\x32-.Volcengine.Base.Models.Base.ResponseMetadata\x12U\n\x06Result\x18\x02 \x01(\x0b\x32\x45.Volcengine.Vod.Models.Business.VodGetSmartStrategyLitePlayInfoResultB\xcc\x01\n)com.volcengine.service.vod.model.responseB\x0bVodResponseP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/response\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Vod\\Models\\Response\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETALLPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetAllPlayInfoResponse']
_VODGETPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetPlayInfoResponse']
_VODGETORIGINALPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetOriginalPlayInfoResponse']
_VODGETPRIVATEDRMPLAYAUTHRESPONSE = DESCRIPTOR.message_types_by_name['VodGetPrivateDrmPlayAuthResponse']
_VODGETHLSDECRYPTIONKEYRESPONSE = DESCRIPTOR.message_types_by_name['VodGetHlsDecryptionKeyResponse']
_VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE = DESCRIPTOR.message_types_by_name['VodGetPlayInfoWithLiveTimeShiftSceneResponse']
_VODUPLOADMEDIARESPONSE = DESCRIPTOR.message_types_by_name['VodUploadMediaResponse']
_VODQUERYUPLOADTASKINFORESPONSE = DESCRIPTOR.message_types_by_name['VodQueryUploadTaskInfoResponse']
_VODURLUPLOADRESPONSE = DESCRIPTOR.message_types_by_name['VodUrlUploadResponse']
_VODAPPLYUPLOADINFORESPONSE = DESCRIPTOR.message_types_by_name['VodApplyUploadInfoResponse']
_VODCOMMITUPLOADINFORESPONSE = DESCRIPTOR.message_types_by_name['VodCommitUploadInfoResponse']
_VODGETMEDIAINFOSRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMediaInfosResponse']
_VODUPDATEMEDIAINFORESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaInfoResponse']
_VODGETRECOMMENDEDPOSTERRESPONSE = DESCRIPTOR.message_types_by_name['VodGetRecommendedPosterResponse']
_VODUPDATEMEDIAPUBLISHSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateMediaPublishStatusResponse']
_VODDELETEMEDIARESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteMediaResponse']
_VODDELETETRANSCODESRESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteTranscodesResponse']
_VODGETMEDIALISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMediaListResponse']
_VODGETSUBTITLEINFOLISTRESPONSE = DESCRIPTOR.message_types_by_name['VodGetSubtitleInfoListResponse']
_VODUPDATESUBTITLESTATUSRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleStatusResponse']
_VODUPDATESUBTITLEINFORESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSubtitleInfoResponse']
_VODGETAUDITFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAuditFramesForAuditResponse']
_VODGETMLFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetMLFramesForAuditResponse']
_VODGETBETTERFRAMESFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetBetterFramesForAuditResponse']
_VODGETAUDIOINFOFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAudioInfoForAuditResponse']
_VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAutomaticSpeechRecognitionForAuditResponse']
_VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE = DESCRIPTOR.message_types_by_name['VodGetAudioEventDetectionForAuditResponse']
_VODCREATEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateVideoClassificationResponse']
_VODUPDATEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateVideoClassificationResponse']
_VODDELETEVIDEOCLASSIFICATIONRESPONSE = DESCRIPTOR.message_types_by_name['VodDeleteVideoClassificationResponse']
_VODLISTVIDEOCLASSIFICATIONSRESPONSE = DESCRIPTOR.message_types_by_name['VodListVideoClassificationsResponse']
_VODLISTSNAPSHOTSRESPONSE = DESCRIPTOR.message_types_by_name['VodListSnapshotsResponse']
_VODSTARTWORKFLOWRESPONSE = DESCRIPTOR.message_types_by_name['VodStartWorkflowResponse']
_VODRETRIEVETRANSCODERESULTRESPONSE = DESCRIPTOR.message_types_by_name['VodRetrieveTranscodeResultResponse']
_VODCREATESPACERESPONSE = DESCRIPTOR.message_types_by_name['VodCreateSpaceResponse']
_VODLISTSPACERESPONSE = DESCRIPTOR.message_types_by_name['VodListSpaceResponse']
_VODGETSPACEDETAILRESPONSE = DESCRIPTOR.message_types_by_name['VodGetSpaceDetailResponse']
_VODUPDATESPACERESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSpaceResponse']
_VODUPDATESPACEUPLOADCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['VodUpdateSpaceUploadConfigResponse']
_VODLISTDOMAINRESPONSE = DESCRIPTOR.message_types_by_name['VodListDomainResponse']
_VODCREATECDNREFRESHTASKRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateCdnRefreshTaskResponse']
_VODCREATECDNPRELOADTASKRESPONSE = DESCRIPTOR.message_types_by_name['VodCreateCdnPreloadTaskResponse']
_VODLISTCDNTASKSRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnTasksResponse']
_VODLISTCDNACCESSLOGRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnAccessLogResponse']
_VODLISTCDNTOPACCESSURLRESPONSE = DESCRIPTOR.message_types_by_name['VodListCdnTopAccessUrlResponse']
_VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeVodDomainBandwidthDataResponse']
_VODCDNSTATISTICSCOMMONRESPONSE = DESCRIPTOR.message_types_by_name['VodCdnStatisticsCommonResponse']
_VODDESCRIBEIPINFORESPONSE = DESCRIPTOR.message_types_by_name['VodDescribeIPInfoResponse']
_VODADDCALLBACKSUBSCRIPTIONRESPONSE = DESCRIPTOR.message_types_by_name['VodAddCallbackSubscriptionResponse']
_VODSETCALLBACKEVENTRESPONSE = DESCRIPTOR.message_types_by_name['VodSetCallbackEventResponse']
_VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['VodGetSmartStrategyLitePlayInfoResponse']
VodGetAllPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetAllPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETALLPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAllPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetAllPlayInfoResponse)

VodGetPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetPlayInfoResponse)

VodGetOriginalPlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetOriginalPlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETORIGINALPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetOriginalPlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetOriginalPlayInfoResponse)

VodGetPrivateDrmPlayAuthResponse = _reflection.GeneratedProtocolMessageType('VodGetPrivateDrmPlayAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPRIVATEDRMPLAYAUTHRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPrivateDrmPlayAuthResponse)
  })
_sym_db.RegisterMessage(VodGetPrivateDrmPlayAuthResponse)

VodGetHlsDecryptionKeyResponse = _reflection.GeneratedProtocolMessageType('VodGetHlsDecryptionKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETHLSDECRYPTIONKEYRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetHlsDecryptionKeyResponse)
  })
_sym_db.RegisterMessage(VodGetHlsDecryptionKeyResponse)

VodGetPlayInfoWithLiveTimeShiftSceneResponse = _reflection.GeneratedProtocolMessageType('VodGetPlayInfoWithLiveTimeShiftSceneResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetPlayInfoWithLiveTimeShiftSceneResponse)
  })
_sym_db.RegisterMessage(VodGetPlayInfoWithLiveTimeShiftSceneResponse)

VodUploadMediaResponse = _reflection.GeneratedProtocolMessageType('VodUploadMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPLOADMEDIARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUploadMediaResponse)
  })
_sym_db.RegisterMessage(VodUploadMediaResponse)

VodQueryUploadTaskInfoResponse = _reflection.GeneratedProtocolMessageType('VodQueryUploadTaskInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODQUERYUPLOADTASKINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodQueryUploadTaskInfoResponse)
  })
_sym_db.RegisterMessage(VodQueryUploadTaskInfoResponse)

VodUrlUploadResponse = _reflection.GeneratedProtocolMessageType('VodUrlUploadResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODURLUPLOADRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUrlUploadResponse)
  })
_sym_db.RegisterMessage(VodUrlUploadResponse)

VodApplyUploadInfoResponse = _reflection.GeneratedProtocolMessageType('VodApplyUploadInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODAPPLYUPLOADINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodApplyUploadInfoResponse)
  })
_sym_db.RegisterMessage(VodApplyUploadInfoResponse)

VodCommitUploadInfoResponse = _reflection.GeneratedProtocolMessageType('VodCommitUploadInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMITUPLOADINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCommitUploadInfoResponse)
  })
_sym_db.RegisterMessage(VodCommitUploadInfoResponse)

VodGetMediaInfosResponse = _reflection.GeneratedProtocolMessageType('VodGetMediaInfosResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIAINFOSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMediaInfosResponse)
  })
_sym_db.RegisterMessage(VodGetMediaInfosResponse)

VodUpdateMediaInfoResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaInfoResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaInfoResponse)

VodGetRecommendedPosterResponse = _reflection.GeneratedProtocolMessageType('VodGetRecommendedPosterResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETRECOMMENDEDPOSTERRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetRecommendedPosterResponse)
  })
_sym_db.RegisterMessage(VodGetRecommendedPosterResponse)

VodUpdateMediaPublishStatusResponse = _reflection.GeneratedProtocolMessageType('VodUpdateMediaPublishStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateMediaPublishStatusResponse)
  })
_sym_db.RegisterMessage(VodUpdateMediaPublishStatusResponse)

VodDeleteMediaResponse = _reflection.GeneratedProtocolMessageType('VodDeleteMediaResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEMEDIARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteMediaResponse)
  })
_sym_db.RegisterMessage(VodDeleteMediaResponse)

VodDeleteTranscodesResponse = _reflection.GeneratedProtocolMessageType('VodDeleteTranscodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETETRANSCODESRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteTranscodesResponse)
  })
_sym_db.RegisterMessage(VodDeleteTranscodesResponse)

VodGetMediaListResponse = _reflection.GeneratedProtocolMessageType('VodGetMediaListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMEDIALISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMediaListResponse)
  })
_sym_db.RegisterMessage(VodGetMediaListResponse)

VodGetSubtitleInfoListResponse = _reflection.GeneratedProtocolMessageType('VodGetSubtitleInfoListResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSUBTITLEINFOLISTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSubtitleInfoListResponse)
  })
_sym_db.RegisterMessage(VodGetSubtitleInfoListResponse)

VodUpdateSubtitleStatusResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLESTATUSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSubtitleStatusResponse)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleStatusResponse)

VodUpdateSubtitleInfoResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSubtitleInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESUBTITLEINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSubtitleInfoResponse)
  })
_sym_db.RegisterMessage(VodUpdateSubtitleInfoResponse)

VodGetAuditFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAuditFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDITFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAuditFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAuditFramesForAuditResponse)

VodGetMLFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetMLFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETMLFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetMLFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetMLFramesForAuditResponse)

VodGetBetterFramesForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetBetterFramesForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETBETTERFRAMESFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetBetterFramesForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetBetterFramesForAuditResponse)

VodGetAudioInfoForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAudioInfoForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOINFOFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAudioInfoForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAudioInfoForAuditResponse)

VodGetAutomaticSpeechRecognitionForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAutomaticSpeechRecognitionForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAutomaticSpeechRecognitionForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAutomaticSpeechRecognitionForAuditResponse)

VodGetAudioEventDetectionForAuditResponse = _reflection.GeneratedProtocolMessageType('VodGetAudioEventDetectionForAuditResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetAudioEventDetectionForAuditResponse)
  })
_sym_db.RegisterMessage(VodGetAudioEventDetectionForAuditResponse)

VodCreateVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodCreateVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodCreateVideoClassificationResponse)

VodUpdateVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodUpdateVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodUpdateVideoClassificationResponse)

VodDeleteVideoClassificationResponse = _reflection.GeneratedProtocolMessageType('VodDeleteVideoClassificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDELETEVIDEOCLASSIFICATIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDeleteVideoClassificationResponse)
  })
_sym_db.RegisterMessage(VodDeleteVideoClassificationResponse)

VodListVideoClassificationsResponse = _reflection.GeneratedProtocolMessageType('VodListVideoClassificationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTVIDEOCLASSIFICATIONSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListVideoClassificationsResponse)
  })
_sym_db.RegisterMessage(VodListVideoClassificationsResponse)

VodListSnapshotsResponse = _reflection.GeneratedProtocolMessageType('VodListSnapshotsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSNAPSHOTSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListSnapshotsResponse)
  })
_sym_db.RegisterMessage(VodListSnapshotsResponse)

VodStartWorkflowResponse = _reflection.GeneratedProtocolMessageType('VodStartWorkflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSTARTWORKFLOWRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodStartWorkflowResponse)
  })
_sym_db.RegisterMessage(VodStartWorkflowResponse)

VodRetrieveTranscodeResultResponse = _reflection.GeneratedProtocolMessageType('VodRetrieveTranscodeResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODRETRIEVETRANSCODERESULTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodRetrieveTranscodeResultResponse)
  })
_sym_db.RegisterMessage(VodRetrieveTranscodeResultResponse)

VodCreateSpaceResponse = _reflection.GeneratedProtocolMessageType('VodCreateSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATESPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateSpaceResponse)
  })
_sym_db.RegisterMessage(VodCreateSpaceResponse)

VodListSpaceResponse = _reflection.GeneratedProtocolMessageType('VodListSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTSPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListSpaceResponse)
  })
_sym_db.RegisterMessage(VodListSpaceResponse)

VodGetSpaceDetailResponse = _reflection.GeneratedProtocolMessageType('VodGetSpaceDetailResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSPACEDETAILRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSpaceDetailResponse)
  })
_sym_db.RegisterMessage(VodGetSpaceDetailResponse)

VodUpdateSpaceResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACERESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSpaceResponse)
  })
_sym_db.RegisterMessage(VodUpdateSpaceResponse)

VodUpdateSpaceUploadConfigResponse = _reflection.GeneratedProtocolMessageType('VodUpdateSpaceUploadConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODUPDATESPACEUPLOADCONFIGRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodUpdateSpaceUploadConfigResponse)
  })
_sym_db.RegisterMessage(VodUpdateSpaceUploadConfigResponse)

VodListDomainResponse = _reflection.GeneratedProtocolMessageType('VodListDomainResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTDOMAINRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListDomainResponse)
  })
_sym_db.RegisterMessage(VodListDomainResponse)

VodCreateCdnRefreshTaskResponse = _reflection.GeneratedProtocolMessageType('VodCreateCdnRefreshTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNREFRESHTASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateCdnRefreshTaskResponse)
  })
_sym_db.RegisterMessage(VodCreateCdnRefreshTaskResponse)

VodCreateCdnPreloadTaskResponse = _reflection.GeneratedProtocolMessageType('VodCreateCdnPreloadTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCREATECDNPRELOADTASKRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCreateCdnPreloadTaskResponse)
  })
_sym_db.RegisterMessage(VodCreateCdnPreloadTaskResponse)

VodListCdnTasksResponse = _reflection.GeneratedProtocolMessageType('VodListCdnTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTASKSRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnTasksResponse)
  })
_sym_db.RegisterMessage(VodListCdnTasksResponse)

VodListCdnAccessLogResponse = _reflection.GeneratedProtocolMessageType('VodListCdnAccessLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNACCESSLOGRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnAccessLogResponse)
  })
_sym_db.RegisterMessage(VodListCdnAccessLogResponse)

VodListCdnTopAccessUrlResponse = _reflection.GeneratedProtocolMessageType('VodListCdnTopAccessUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODLISTCDNTOPACCESSURLRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodListCdnTopAccessUrlResponse)
  })
_sym_db.RegisterMessage(VodListCdnTopAccessUrlResponse)

VodDescribeVodDomainBandwidthDataResponse = _reflection.GeneratedProtocolMessageType('VodDescribeVodDomainBandwidthDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeVodDomainBandwidthDataResponse)
  })
_sym_db.RegisterMessage(VodDescribeVodDomainBandwidthDataResponse)

VodCdnStatisticsCommonResponse = _reflection.GeneratedProtocolMessageType('VodCdnStatisticsCommonResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODCDNSTATISTICSCOMMONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodCdnStatisticsCommonResponse)
  })
_sym_db.RegisterMessage(VodCdnStatisticsCommonResponse)

VodDescribeIPInfoResponse = _reflection.GeneratedProtocolMessageType('VodDescribeIPInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODDESCRIBEIPINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodDescribeIPInfoResponse)
  })
_sym_db.RegisterMessage(VodDescribeIPInfoResponse)

VodAddCallbackSubscriptionResponse = _reflection.GeneratedProtocolMessageType('VodAddCallbackSubscriptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODADDCALLBACKSUBSCRIPTIONRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodAddCallbackSubscriptionResponse)
  })
_sym_db.RegisterMessage(VodAddCallbackSubscriptionResponse)

VodSetCallbackEventResponse = _reflection.GeneratedProtocolMessageType('VodSetCallbackEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODSETCALLBACKEVENTRESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodSetCallbackEventResponse)
  })
_sym_db.RegisterMessage(VodSetCallbackEventResponse)

VodGetSmartStrategyLitePlayInfoResponse = _reflection.GeneratedProtocolMessageType('VodGetSmartStrategyLitePlayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE,
  '__module__' : 'vod.response.response_vod_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Response.VodGetSmartStrategyLitePlayInfoResponse)
  })
_sym_db.RegisterMessage(VodGetSmartStrategyLitePlayInfoResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.responseB\013VodResponseP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/response\240\001\001\330\001\001\312\002 Volc\\Service\\Vod\\Models\\Response\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETALLPLAYINFORESPONSE._serialized_start=336
  _VODGETALLPLAYINFORESPONSE._serialized_end=506
  _VODGETPLAYINFORESPONSE._serialized_start=509
  _VODGETPLAYINFORESPONSE._serialized_end=672
  _VODGETORIGINALPLAYINFORESPONSE._serialized_start=675
  _VODGETORIGINALPLAYINFORESPONSE._serialized_end=858
  _VODGETPRIVATEDRMPLAYAUTHRESPONSE._serialized_start=861
  _VODGETPRIVATEDRMPLAYAUTHRESPONSE._serialized_end=1048
  _VODGETHLSDECRYPTIONKEYRESPONSE._serialized_start=1051
  _VODGETHLSDECRYPTIONKEYRESPONSE._serialized_end=1234
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE._serialized_start=1237
  _VODGETPLAYINFOWITHLIVETIMESHIFTSCENERESPONSE._serialized_end=1448
  _VODUPLOADMEDIARESPONSE._serialized_start=1451
  _VODUPLOADMEDIARESPONSE._serialized_end=1611
  _VODQUERYUPLOADTASKINFORESPONSE._serialized_start=1614
  _VODQUERYUPLOADTASKINFORESPONSE._serialized_end=1781
  _VODURLUPLOADRESPONSE._serialized_start=1784
  _VODURLUPLOADRESPONSE._serialized_end=1947
  _VODAPPLYUPLOADINFORESPONSE._serialized_start=1950
  _VODAPPLYUPLOADINFORESPONSE._serialized_end=2125
  _VODCOMMITUPLOADINFORESPONSE._serialized_start=2128
  _VODCOMMITUPLOADINFORESPONSE._serialized_end=2305
  _VODGETMEDIAINFOSRESPONSE._serialized_start=2308
  _VODGETMEDIAINFOSRESPONSE._serialized_end=2477
  _VODUPDATEMEDIAINFORESPONSE._serialized_start=2479
  _VODUPDATEMEDIAINFORESPONSE._serialized_end=2580
  _VODGETRECOMMENDEDPOSTERRESPONSE._serialized_start=2583
  _VODGETRECOMMENDEDPOSTERRESPONSE._serialized_end=2758
  _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE._serialized_start=2760
  _VODUPDATEMEDIAPUBLISHSTATUSRESPONSE._serialized_end=2870
  _VODDELETEMEDIARESPONSE._serialized_start=2873
  _VODDELETEMEDIARESPONSE._serialized_end=3038
  _VODDELETETRANSCODESRESPONSE._serialized_start=3041
  _VODDELETETRANSCODESRESPONSE._serialized_end=3216
  _VODGETMEDIALISTRESPONSE._serialized_start=3219
  _VODGETMEDIALISTRESPONSE._serialized_end=3386
  _VODGETSUBTITLEINFOLISTRESPONSE._serialized_start=3389
  _VODGETSUBTITLEINFOLISTRESPONSE._serialized_end=3570
  _VODUPDATESUBTITLESTATUSRESPONSE._serialized_start=3573
  _VODUPDATESUBTITLESTATUSRESPONSE._serialized_end=3756
  _VODUPDATESUBTITLEINFORESPONSE._serialized_start=3758
  _VODUPDATESUBTITLEINFORESPONSE._serialized_end=3862
  _VODGETAUDITFRAMESFORAUDITRESPONSE._serialized_start=3865
  _VODGETAUDITFRAMESFORAUDITRESPONSE._serialized_end=4049
  _VODGETMLFRAMESFORAUDITRESPONSE._serialized_start=4052
  _VODGETMLFRAMESFORAUDITRESPONSE._serialized_end=4233
  _VODGETBETTERFRAMESFORAUDITRESPONSE._serialized_start=4236
  _VODGETBETTERFRAMESFORAUDITRESPONSE._serialized_end=4427
  _VODGETAUDIOINFOFORAUDITRESPONSE._serialized_start=4430
  _VODGETAUDIOINFOFORAUDITRESPONSE._serialized_end=4615
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE._serialized_start=4618
  _VODGETAUTOMATICSPEECHRECOGNITIONFORAUDITRESPONSE._serialized_end=4837
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE._serialized_start=4840
  _VODGETAUDIOEVENTDETECTIONFORAUDITRESPONSE._serialized_end=5045
  _VODCREATEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5048
  _VODCREATEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5241
  _VODUPDATEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5243
  _VODUPDATEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5354
  _VODDELETEVIDEOCLASSIFICATIONRESPONSE._serialized_start=5356
  _VODDELETEVIDEOCLASSIFICATIONRESPONSE._serialized_end=5467
  _VODLISTVIDEOCLASSIFICATIONSRESPONSE._serialized_start=5470
  _VODLISTVIDEOCLASSIFICATIONSRESPONSE._serialized_end=5657
  _VODLISTSNAPSHOTSRESPONSE._serialized_start=5660
  _VODLISTSNAPSHOTSRESPONSE._serialized_end=5824
  _VODSTARTWORKFLOWRESPONSE._serialized_start=5827
  _VODSTARTWORKFLOWRESPONSE._serialized_end=5998
  _VODRETRIEVETRANSCODERESULTRESPONSE._serialized_start=6001
  _VODRETRIEVETRANSCODERESULTRESPONSE._serialized_end=6175
  _VODCREATESPACERESPONSE._serialized_start=6177
  _VODCREATESPACERESPONSE._serialized_end=6274
  _VODLISTSPACERESPONSE._serialized_start=6277
  _VODLISTSPACERESPONSE._serialized_end=6434
  _VODGETSPACEDETAILRESPONSE._serialized_start=6437
  _VODGETSPACEDETAILRESPONSE._serialized_end=6599
  _VODUPDATESPACERESPONSE._serialized_start=6601
  _VODUPDATESPACERESPONSE._serialized_end=6698
  _VODUPDATESPACEUPLOADCONFIGRESPONSE._serialized_start=6700
  _VODUPDATESPACEUPLOADCONFIGRESPONSE._serialized_end=6809
  _VODLISTDOMAINRESPONSE._serialized_start=6812
  _VODLISTDOMAINRESPONSE._serialized_end=6977
  _VODCREATECDNREFRESHTASKRESPONSE._serialized_start=6980
  _VODCREATECDNREFRESHTASKRESPONSE._serialized_end=7158
  _VODCREATECDNPRELOADTASKRESPONSE._serialized_start=7161
  _VODCREATECDNPRELOADTASKRESPONSE._serialized_end=7339
  _VODLISTCDNTASKSRESPONSE._serialized_start=7342
  _VODLISTCDNTASKSRESPONSE._serialized_end=7506
  _VODLISTCDNACCESSLOGRESPONSE._serialized_start=7509
  _VODLISTCDNACCESSLOGRESPONSE._serialized_end=7686
  _VODLISTCDNTOPACCESSURLRESPONSE._serialized_start=7689
  _VODLISTCDNTOPACCESSURLRESPONSE._serialized_end=7872
  _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE._serialized_start=7875
  _VODDESCRIBEVODDOMAINBANDWIDTHDATARESPONSE._serialized_end=8080
  _VODCDNSTATISTICSCOMMONRESPONSE._serialized_start=8083
  _VODCDNSTATISTICSCOMMONRESPONSE._serialized_end=8266
  _VODDESCRIBEIPINFORESPONSE._serialized_start=8269
  _VODDESCRIBEIPINFORESPONSE._serialized_end=8431
  _VODADDCALLBACKSUBSCRIPTIONRESPONSE._serialized_start=8433
  _VODADDCALLBACKSUBSCRIPTIONRESPONSE._serialized_end=8542
  _VODSETCALLBACKEVENTRESPONSE._serialized_start=8544
  _VODSETCALLBACKEVENTRESPONSE._serialized_end=8646
  _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE._serialized_start=8649
  _VODGETSMARTSTRATEGYLITEPLAYINFORESPONSE._serialized_end=8850
# @@protoc_insertion_point(module_scope)
